#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.CSharp.NUnitUnitTest.Properties;

#endregion

namespace Chili.Opf3.Wizard.CSharp.NUnitUnitTest
{
	/// <summary>
	/// This class creates the test methods for the unit test.
	/// </summary>
	internal sealed class MethodTestsCreator
	{
		public const string OPENING_BRACKETS = "{";
		public const string CLOSING_BRACKETS = "}";
		private Template _template;
		private UnitTest _test;
		private Project _project;
		private StateBag _stateBag;

		/// <summary>
		/// Creates a new instance of the <see cref="MethodTestsCreator">MethodTestsCreator Class</see>.
		/// </summary>
		/// <param name="template">The template for the unit test creator.</param>
		/// <param name="project">The project of the wizard.</param>
		/// <param name="test">The current test.</param>
		/// <param name="stateBag">The state bag containing the settings of the plug-in.</param>
		public MethodTestsCreator(Template template, UnitTest test, Project project, StateBag stateBag)
		{
			if (template == null)
				throw new ArgumentNullException("template", "Template is null.");
			if (project == null)
				throw new ArgumentNullException("project", "Project is null.");
			if (test == null)
				throw new ArgumentNullException("test", "Test is null.");
			if (stateBag == null)
				throw new ArgumentNullException("stateBag", "StateBag is null.");

			_template = template;
			_test = test;
			_project = project;
			_stateBag = stateBag;
		}

		/// <summary>
		/// Creates the test methods and returns them.
		/// </summary>
		/// <returns></returns>
		public string CreateTestMethods()
		{
			string result = string.Empty;

			foreach (Field field in _test.Table.Fields)
			{
				// Skip fields that are not created, autonumber or foreign key in a relation.
				if (!field.Generate || field.AutoNumber || UnitTestCreator.IsForeignKeyInRelation(field, _test, _project))
					continue;

				// Add a new line if we are in the >= second property.
				if (result.Length > 0)
					result += "\r\n";

				if (field.Type == typeof(string))
					result += CreateMethodStringTest(field);
				else
					result += CreateMethodOtherTest(field);
			}

			return string.Format(_template.GetValue("//methodTestRegion"), result);
		}

		/// <summary>
		/// Creates the test method for items that are strings.
		/// </summary>
		/// <param name="field">The field for that the test is created.</param>
		private string CreateMethodStringTest(Field field)
		{
			string testMethodName = _stateBag.MethodNameTemplate.Replace(Resources.MethodNameVariable, field.PropertyName);
			string typeInitializer = _template.GetValue(string.Format("//initializes/initialize[@id = '{0}']", field.Type));
			string nullableTest = string.Empty;

			if (UnitTestCreator.IsNullable(field))
				nullableTest = string.Format(_template.GetValue("//nullableTest"), field.PropertyName, _project.Namespace, _test.Table.PersistentName);

			return string.Format(_template.GetValue("//methodStringTest"), OPENING_BRACKETS, CLOSING_BRACKETS, testMethodName,
				_test.Table.PersistentName, UnitTestCreator.GetCSharpType(_template, field), typeInitializer, field.PropertyName, _project.Namespace,
				field.Length - 1, field.Length + 1, nullableTest);
		}

		/// <summary>
		/// Creates the test method for items other then a string.
		/// </summary>
		/// <param name="field">The field for that the test is created.</param>
		private string CreateMethodOtherTest(Field field)
		{
			string testMethodName = _stateBag.MethodNameTemplate.Replace(Resources.MethodNameVariable, field.PropertyName);
			string typeInitializer = _template.GetValue(string.Format("//initializes/initialize[@id = '{0}']", field.Type));
			string nullableTest = string.Empty;

			if (UnitTestCreator.IsNullable(field))
				nullableTest = string.Format(_template.GetValue("//nullableTest"), field.PropertyName, _project.Namespace, _test.Table.PersistentName);

			return string.Format(_template.GetValue("//methodOtherTest"), OPENING_BRACKETS, CLOSING_BRACKETS, testMethodName,
				_test.Table.PersistentName, UnitTestCreator.GetCSharpType(_template, field), typeInitializer, field.PropertyName, _project.Namespace, 
				nullableTest);
		}
	}
}
