#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.CSharp.NUnitUnitTest
{
	/// <summary>
	/// This class holds the state of the plugin.
	/// </summary>
	[Serializable]
	public sealed class StateBag
	{
		private string _fileNameTemplate;
		private string _classNameTemplate;
		private string _methodNameTemplate;
		private string _testNamespace;
		private bool _createMethodTests = true;
		private bool _createRelationTests = true;
		private bool _createPersistentIOTest = true;

		/// <summary>
		/// Specifies whether the persistent IO test is created.
		/// </summary>
		public bool CreatePersistentIOTest
		{
			get { return _createPersistentIOTest; }
			set { _createPersistentIOTest = value; }
		}

		/// <summary>
		/// Specifies whether relation tests are created.
		/// </summary>
		public bool CreateRelationTests
		{
			get { return _createRelationTests; }
			set { _createRelationTests = value; }
		}

		/// <summary>
		/// Specifies whether method tests are created.
		/// </summary>
		public bool CreateMethodTests
		{
			get { return _createMethodTests; }
			set { _createMethodTests = value; }
		}

		/// <summary>
		/// Specifies the template name for the file name.
		/// </summary>
		public string FileNameTemplate
		{
			get { return _fileNameTemplate; }
			set { _fileNameTemplate = value; }
		}

		/// <summary>
		/// Specifies the template name for the class name.
		/// </summary>
		public string ClassNameTemplate
		{
			get { return _classNameTemplate; }
			set { _classNameTemplate = value; }
		}
		
		/// <summary>
		/// Specifies the template name for the method name.
		/// </summary>
		public string MethodNameTemplate
		{
			get { return _methodNameTemplate; }
			set { _methodNameTemplate = value; }
		}

		/// <summary>
		/// Specifies the namespace for the tests.
		/// </summary>
		public string TestNamespace
		{
			get { return _testNamespace; }
			set { _testNamespace = value; }
		}

        /// <summary>
        /// Serialize the StateBag state in xml.
        /// </summary>
        public XmlNode Serialize(XmlDocument xml)
        {
            XmlElement s = xml.CreateElement("statebag");
            s.AppendChild(CreateXmlElement(xml, "FileNameTemplate", _fileNameTemplate));
            s.AppendChild(CreateXmlElement(xml, "ClassNameTemplate", _classNameTemplate));
            s.AppendChild(CreateXmlElement(xml, "MethodNameTemplate", _methodNameTemplate));
            s.AppendChild(CreateXmlElement(xml, "TestNamespace", _testNamespace));
            s.AppendChild(CreateXmlElement(xml, "CreateMethodTests", _createMethodTests.ToString()));
            s.AppendChild(CreateXmlElement(xml, "CreateRelationTests", _createRelationTests.ToString()));
            s.AppendChild(CreateXmlElement(xml, "CreatePersistentIOTest", _createPersistentIOTest.ToString()));
            return s;
        }

        /// <summary>
        /// Deserialize the StateBag from xml.
        /// </summary>
        public void Deserialize(Project project, XmlDocument xml, XmlNode d)
        {
            XmlNode p = d.SelectSingleNode("./statebag");

            if (p != null)
            {
                _fileNameTemplate = p.SelectSingleNode("./FileNameTemplate").InnerText;
                _classNameTemplate = p.SelectSingleNode("./ClassNameTemplate").InnerText;
                _methodNameTemplate = p.SelectSingleNode("./MethodNameTemplate").InnerText;
                _testNamespace = p.SelectSingleNode("./TestNamespace").InnerText;
                _createMethodTests = bool.Parse(p.SelectSingleNode("./CreateMethodTests").InnerText);
                _createRelationTests = bool.Parse(p.SelectSingleNode("./CreateRelationTests").InnerText);
                _createPersistentIOTest = bool.Parse(p.SelectSingleNode("./CreatePersistentIOTest").InnerText);
            }
        }

        /// <summary>
        /// Creates an xml element with the given name and value.
        /// </summary>
        /// <param name="name">The name of the element.</param>
        /// <param name="value">The value of the element.</param>
        private XmlNode CreateXmlElement(XmlDocument xml, string name, string value)
        {
            XmlElement e = xml.CreateElement(name);
            e.AppendChild(xml.CreateTextNode(value));

            return e;
        }
	}
}
