#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.CSharp.NUnitUnitTest.Properties;

#endregion

namespace Chili.Opf3.Wizard.CSharp.NUnitUnitTest
{
	/// <summary>
	/// This class creates the test object instance code for the unit test.
	/// </summary>
	internal class TestObjectInstanceCreator
	{
		private Template _template;
		private UnitTest _test;
		private Project _project;
		private StateBag _stateBag;

		/// <summary>
		/// Creates a new instance of the <see cref="TestObjectInstanceCreator">TestObjectInstanceCreator Class</see>.
		/// </summary>
		/// <param name="template">The template for the unit test creator.</param>
		/// <param name="project">The project of the wizard.</param>
		/// <param name="test">The current test.</param>
		/// <param name="stateBag">The state bag containing the settings of the plug-in.</param>
		public TestObjectInstanceCreator(Template template, UnitTest test, Project project, StateBag stateBag)
		{
			if (template == null)
				throw new ArgumentNullException("template", "Template is null.");
			if (project == null)
				throw new ArgumentNullException("project", "Project is null.");
			if (test == null)
				throw new ArgumentNullException("test", "Test is null.");
			if (stateBag == null)
				throw new ArgumentNullException("stateBag", "StateBag is null.");

			_template = template;
			_test = test;
			_project = project;
			_stateBag = stateBag;
		}

		/// <summary>
		/// Creates the code for the test object instance.
		/// </summary>
		/// <returns></returns>
		public string CreateTestObjectInstanceCode()
		{
			string properties = string.Empty;

			foreach (Field field in _test.Table.Fields)
			{
				// Skip fields that are not created, autonumber or foreign key in a relation.
				if (!field.Generate || field.AutoNumber || UnitTestCreator.IsForeignKeyInRelation(field, _test, _project))
					continue;

				properties += string.Format(_template.GetValue("//setProperty"), field.PropertyName, GetMethodCall(field));
			}

			return string.Format(_template.GetValue("//instance"), _test.Table.PersistentName, properties);
		}

		/// <summary>
		/// Gets the method call for the given field.
		/// </summary>
		/// <param name="field"></param>
		private string GetMethodCall(Field field)
		{
			if (field == null)
				return "null";

			string call = _template.GetValue(string.Format("//methodCalls/call[@type = '{0}']", field.Type));
			if (field.Type == typeof(string))
				return string.Format(call, field.Length.ToString());
			return call;
		}
	}
}
