#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared.UI;
using Chili.Opf3.Wizard.CSharp.NUnitUnitTest.Properties;
using System.Text.RegularExpressions;

#endregion

namespace Chili.Opf3.Wizard.CSharp.NUnitUnitTest.UI
{
	/// <summary>
	/// This class allows to customize the unit tests created for the persistent objects.
	/// </summary>
	public partial class UnitTestPage : Page
	{
		private UnitTestProvider _provider;
		private StateBag _statebag;

		/// <summary>
		/// Creates a new instance of the <see cref="UnitTestPage">UnitTestPage Class</see>.
		/// </summary>
		/// <param name="provider">The provider itself.</param>
        public UnitTestPage(UnitTestProvider provider, StateBag statebag) 
            : base(provider)
		{
			InitializeComponent();

			if (provider == null)
				throw new ArgumentNullException("provider", "Provider is null.");
            if (statebag == null)
                throw new ArgumentNullException("statebag", "Statebag is null.");
			_provider = provider;
            _statebag = statebag; 
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		/// <param name="project">The current project.</param>
		public override void PageOpening(Project project)
		{
			SetHeaderTitle(Resources.UnitTestsHeaderTitle);
			SetHeaderDescription(Resources.UnitTestsHeaderDescription);

			if (_statebag.FileNameTemplate != null)
				fileNameTextBox.Text = _statebag.FileNameTemplate;
			if (_statebag.ClassNameTemplate != null)
				classNameTextBox.Text = _statebag.ClassNameTemplate;
			if (_statebag.MethodNameTemplate != null)
				methodNameTextBox.Text = _statebag.MethodNameTemplate;
			if (_statebag.TestNamespace != null)
				namespaceTextBox.Text = _statebag.TestNamespace;

			createPersistentIOTestCheckBox.Checked = _statebag.CreatePersistentIOTest;
			createRelationsTestCheckBox.Checked = _statebag.CreateRelationTests;
			createTestMethodsCheckBox.Checked = _statebag.CreateMethodTests;
		}

		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
			if (!next)
				return true;

			if (fileNameTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.InvalidFileNameTemplateText, Resources.InvalidFileNameTemplateTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);
				fileNameTextBox.Focus();
				return false;
			}
			if (classNameTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.InvalidClassNameTemplateText, Resources.InvalidClassNameTemplateTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);
				classNameTextBox.Focus();
				return false;
			}
			if (methodNameTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.InvalidMethodNameTemplateText, Resources.InvalidMethodNameTemplateTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);
				methodNameTextBox.Focus();
				return false;
			}
			if (namespaceTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.InvalidNamespaceText, Resources.InvalidNamespaceTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);
				namespaceTextBox.Focus();
				return false;
			}
			if (!createTestMethodsCheckBox.Checked && !createPersistentIOTestCheckBox.Checked && !createRelationsTestCheckBox.Checked)
			{
				MessageBox.Show(Resources.SelectOneTestText, Resources.SelectOneTestTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}

			_statebag.FileNameTemplate = fileNameTextBox.Text;
			_statebag.ClassNameTemplate = classNameTextBox.Text;
			_statebag.MethodNameTemplate = methodNameTextBox.Text;
			_statebag.TestNamespace = namespaceTextBox.Text;

			_statebag.CreateMethodTests = createTestMethodsCheckBox.Checked;
			_statebag.CreatePersistentIOTest = createPersistentIOTestCheckBox.Checked;
			_statebag.CreateRelationTests = createRelationsTestCheckBox.Checked;

			return true;
		}
	}
}
