#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.CSharp.NUnitUnitTest.Properties;

#endregion

namespace Chili.Opf3.Wizard.CSharp.NUnitUnitTest
{
    /// <summary>
    /// This class represents one unit test that is created from a table.
    /// </summary>
    internal sealed class UnitTest : IGeneratedObject
    {
        private Table _table;
		private StateBag _stateBag;
		private string _id = Guid.NewGuid().ToString();

        /// <summary>
		/// Creates a new instance of the <see cref="UnitTest">UnitTest Class</see>.
		/// </summary>
		/// <param name="stateBag">The state bag of the plug-in.</param>
		/// <param name="table">The table associated with the unit test.</param>
		public UnitTest(StateBag stateBag, Table table)
		{
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");
			if (stateBag == null)
				throw new ArgumentNullException("stateBag", "StateBag is null.");

			_table = table;
			_stateBag = stateBag;
		}

		/// <summary>
		/// Specifies the table associated with the unit test.
		/// </summary>
		public Table Table
		{
			get { return _table; }
		}

        #region IGeneratedObject Members

		/// <summary>
		/// Returns the ID of the object. This is a unique identifier that is required for synchronization with the display.
		/// </summary>
		public string ID
        {
            get { return _id; }
        }

		/// <summary>
		/// Returns the name of the object. Is displayed in the list when generating the objects.
		/// </summary>
		public string Name
        {
            get { return _stateBag.ClassNameTemplate.Replace(Resources.ClassNameVariable, _table.PersistentName); }
        }

        #endregion
    }
}
