#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.CSharp.Searcher
{
	/// <summary>
	/// This class represents one searcher that is created for a persistent.
	/// </summary>
	public sealed class Searcher : IGeneratedObject
	{
		private const string SEARCHER_NAME_TEMPLATE = "{0}Searcher";
		private string _id = Guid.NewGuid().ToString();

		private Table _table;
		private string _searcherName;
		private bool _generate = true;
        private List<SearcherMethod> _methods = new List<SearcherMethod>();

		/// <summary>
        /// Creates a new instance of the <see cref="Searcher">Searcher Class</see>.
		/// </summary>
        /// <param name="table">The table associated with the searcher.</param>
		public Searcher(Table table)
		{
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");
			_table = table;
			if (!_table.Generate)
				_generate = false;
		}

		/// <summary>
		/// Specifies the table associated with the searcher.
		/// </summary>
		public Table Table
		{
			get { return _table; }
		}

		/// <summary>
        /// Specifies whether the searcher is generated.
		/// </summary>
		public bool Generate
		{
			get { return _generate; }
			set { _generate = value; }
		}

        /// <summary>
        /// Returns the methods for the searcher.
        /// </summary>
        public List<SearcherMethod> Methods
        {
            get { return _methods; }
            set { _methods=value; }
        }

		/// <summary>
        /// Returns the name for the searcher.
		/// </summary>
		public string SearcherName
		{
			get
			{
				if (_searcherName == null)
					return string.Format(SEARCHER_NAME_TEMPLATE, _table.PersistentName);
				else
					return _searcherName;
			}
			set
			{
				if (value == null)
					throw new ArgumentNullException("value", "SearcherName is null.");
				if (value.Length == 0)
					throw new ArgumentException("SearcherName must be longer then 0 characters.");

                // Set the value to null if the name of the searcher is the same as the one of the persistent.
				if (value == string.Format(SEARCHER_NAME_TEMPLATE, _table.PersistentName))
					value = null;

				_searcherName = value;
			}
		}

        public void BuildMethods()
        {
            // build  index based Method
            foreach (Index index in _table.Indexes)
            {
                string returntype = (index.PrimaryKey ? "{0}" : "ObjectSet<{0}>");
                string name = "GetBy" + NameUtility.GetPropertyName(index.Name);

				// We need to copy the fields into a list of searcher fields.
				List<SearcherField> fields = new List<SearcherField>();
				foreach (Field f in index.Fields)
				{
					fields.Add(new SearcherField(f, "="));
				}

                _methods.Add(new SearcherMethod(name, returntype, fields));
            }
        }

		#region IGeneratedObject Members

		/// <summary>
		/// Returns the ID of the object. This is a unique identifier that
		/// is required for synchronization with the display.
		/// </summary>
		public string ID
		{
			get { return _id; }
		}

		/// <summary>
		/// Returns the name of the object. Is displayed in the list when generating
		/// the objects.
		/// </summary>
		public string Name
		{
			get { return this.SearcherName; }
		}

		#endregion
	}
}
