#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared.Storages;

#endregion

namespace Chili.Opf3.Wizard.CSharp.Searcher
{
    /// <summary>
    /// This class represents one method of the searcher.
    /// </summary>
    public class SearcherMethod
    {
        private string _methodName;
        private string _returntype;
        private bool _generate = true;
		private List<SearcherField> _fields = new List<SearcherField>();

        /// <summary>
        /// Creates a new instance of the <see cref="SearcherMethod">SearcherMethod Class</see>.
		/// </summary>
        public SearcherMethod()
        {
        }

        /// <summary>
        /// Creates a new instance of the <see cref="SearcherMethod">SearcherMethod Class</see>.
		/// </summary>
		/// <param name="i"></param>
		public SearcherMethod(String methodName, String returntype, List<SearcherField> fields)
			: this()
		{
            if (methodName == null)
                throw new ArgumentNullException("value", "MethodName is null.");
            if (methodName.Length == 0)
                throw new ArgumentException("MethodName must be longer then 0 characters.");
            if (returntype == null)
                throw new ArgumentNullException("value", "ReturnType is null.");
            if (returntype.Length == 0)
                throw new ArgumentException("ReturnType must be longer then 0 characters.");

            _methodName = methodName;
            _returntype = returntype;

            if (fields != null)
                _fields.AddRange(fields);
        }

        /// <summary>
        /// Specifies whether the method is generated.
        /// </summary>
        public bool Generate
        {
            get { return _generate; }
            set { _generate = value; }
        }

        /// <summary>
        /// Returns the name for the method.
        /// </summary>
        public string Name
        {
            get
            {
                return _methodName;
            }
            set
            {
                if (value == null)
                    throw new ArgumentNullException("value", "MethodName is null.");
                if (value.Length == 0)
                    throw new ArgumentException("MethodName must be longer then 0 characters.");

                _methodName = value;
            }
        }

        /// <summary>
        /// Returns the return type for the method.
        /// </summary>
        public string ReturnType
        {
            get
            {
                return _returntype;
            }
            set
            {
                if (value == null)
                    throw new ArgumentNullException("value", "ReturnType is null.");
                if (value.Length == 0)
                    throw new ArgumentException("ReturnType must be longer then 0 characters.");

                _returntype = value;
            }
        }


        /// <summary>
        /// Return the fields list of the method.
        /// </summary>
		public List<SearcherField> Fields
        {
            get { return _fields; }
            set { _fields = value; }
        }

        /// <summary>
        /// The index comma delimited fields name list.
        /// </summary>
        public string FieldsName
        {
            get
            {
                string buff = null;
				foreach (SearcherField field in _fields)
                    buff += String.Format((buff == null) ? "{0}" : ",{0}", field.Field.PropertyName);

                return buff;
            }
        }
        
    }
}
