#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.CSharp.Searcher
{
	/// <summary>
	/// This class holds the state of the plugin.
	/// </summary>
	[Serializable]
	public sealed class StateBag
	{
        private string _businessserver = "BusinessServer.Instance.Context";
        private string _derivefrom = "ObjectSearcher<{0}>";
		private bool _createstatic = false;
        private string _usingdirective;

		/// <summary>
		/// Specifies whether the searcher is created static.
		/// </summary>
		public bool CreateStatic
		{
            get { return _createstatic; }
            set { _createstatic = value; }
		}

        /// <summary>
        /// Specifies additional using directive.
        /// </summary>
        public string UsingDirective
        {
            get { return _usingdirective; }
            set { _usingdirective = value; }
        }

		/// <summary>
		/// Specifies the template name for the file name.
		/// </summary>
		public string DeriveFrom
		{
            get { return _derivefrom; }
            set { _derivefrom = value; }
		}

		/// <summary>
		/// Specifies the name of te businessserver instance.
		/// </summary>
		public string BusinessServer
		{
            get { return _businessserver; }
            set { _businessserver = value; }
		}

        /// <summary>
        /// Serialize the StateBag state in xml.
        /// </summary>
        public XmlNode Serialize(XmlDocument xml)
        {
            XmlElement s = xml.CreateElement("statebag");
            s.AppendChild(CreateXmlElement(xml, "DeriveFrom", _derivefrom));
            s.AppendChild(CreateXmlElement(xml, "BusinessServer", _businessserver));
            s.AppendChild(CreateXmlElement(xml, "CreateStatic", _createstatic.ToString()));
            s.AppendChild(CreateXmlElement(xml, "UsingDirective", _usingdirective));
            return s;
        }

        /// <summary>
        /// Deserialize the StateBag from xml.
        /// </summary>
        public void Deserialize(Project project, XmlDocument xml, XmlNode d)
        {
            XmlNode p = d.SelectSingleNode("./statebag");

            if (p != null)
            {
                try
                {
                    _derivefrom = p.SelectSingleNode("./DeriveFrom").InnerText;
                    _businessserver = p.SelectSingleNode("./BusinessServer").InnerText;
                    _createstatic = bool.Parse(p.SelectSingleNode("./CreateStatic").InnerText);
                    _usingdirective = p.SelectSingleNode("./UsingDirective").InnerText;
                }
                catch
                {
                }
            }
        }

        /// <summary>
        /// Creates an xml element with the given name and value.
        /// </summary>
        /// <param name="name">The name of the element.</param>
        /// <param name="value">The value of the element.</param>
        private XmlNode CreateXmlElement(XmlDocument xml, string name, string value)
        {
            XmlElement e = xml.CreateElement(name);
            e.AppendChild(xml.CreateTextNode(value));

            return e;
        }
	}
}
