#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;

using Chili.Opf3.Wizard.CSharp.Searcher;
using Chili.Opf3.Wizard.CSharp.Searcher.Properties;
using Chili.Opf3.Wizard.Shared.UI;

#endregion

namespace Chili.Opf3.Wizard.CSharp.Searcher.UI
{
	/// <summary>
	/// This class allows to customize the searchers that are going created.
	/// </summary>
	public partial class AdditionalDataPage : Page
	{
		private SearcherProvider _provider;
		private Project _project;
        private StateBag _statebag;

		/// <summary>
		/// Creates a new instance of the <see cref="SearcherPage">SearcherPage Class</see>.
		/// </summary>
		/// <param name="provider">The provider itself.</param>
        public AdditionalDataPage(SearcherProvider provider,StateBag statebag)
            : base(provider)
		{
			InitializeComponent();

			if (provider == null)
				throw new ArgumentNullException("provider", "Provider is null.");
            if (statebag == null)
                throw new ArgumentNullException("statebag", "Satebag is null.");
			_provider = provider;
            _statebag = statebag;
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		/// <param name="project">The current project.</param>
		public override void PageOpening(Project project)
		{
			// Set the current project.
			_project = project;

			SetHeaderTitle(Resources.SearchersHeaderTitle);
			SetHeaderDescription(Resources.SearchersHeaderDescription);

			// Bind the data.
            staticRadioButton.Checked = _statebag.CreateStatic;  
            derivedRadioButton.Checked = ! _statebag.CreateStatic;
            baseclassTextBox.Text = _statebag.DeriveFrom;
            boTextBox.Text = _statebag.BusinessServer;
            usingDirectiveTextBox.Text = _statebag.UsingDirective;
		}

		
		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
            _statebag.CreateStatic = staticRadioButton.Checked;
            _statebag.DeriveFrom = baseclassTextBox.Text;
            _statebag.BusinessServer = boTextBox.Text;
            _statebag.UsingDirective = usingDirectiveTextBox.Text; 

			return true;
		}

        private void RadioButton_CheckedChanged(object sender, EventArgs e)
        {
            baseclassTextBox.Enabled = derivedRadioButton.Checked;
            boTextBox.Enabled = !derivedRadioButton.Checked;

            baseclassLabel.Enabled = derivedRadioButton.Checked;
            businessserverLabel.Enabled = !derivedRadioButton.Checked;
        }
	}
}
