#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.CSharp.InterfacesProvider
{
	/// <summary>
	/// This class represents one interface that is created for a persistent.
	/// </summary>
	public sealed class Interface : IGeneratedObject
	{
		private const string INTERFACE_NAME_TEMPLATE = "I{0}";
		private string _id = Guid.NewGuid().ToString();

		private Table _table;
		private string _interfaceName;
		private bool _generate = true;

		/// <summary>
		/// Creates a new instance of the <see cref="Interface">Interface Class</see>.
		/// </summary>
		/// <param name="table">The table associated with the interface.</param>
		public Interface(Table table)
		{
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");
			_table = table;
			if (!_table.Generate)
				_generate = false;
		}

		/// <summary>
		/// Specifies the table associated with the interface.
		/// </summary>
		public Table Table
		{
			get { return _table; }
		}

		/// <summary>
		/// Specifies whether the interface is generated.
		/// </summary>
		public bool Generate
		{
			get { return _generate; }
			set { _generate = value; }
		}

		/// <summary>
		/// Returns the name for the interface.
		/// </summary>
		public string InterfaceName
		{
			get
			{
				if (_interfaceName == null)
					return string.Format(INTERFACE_NAME_TEMPLATE, _table.PersistentName);
				else
					return _interfaceName;
			}
			set
			{
				if (value == null)
					throw new ArgumentNullException("value", "InterfaceName is null.");
				if (value.Length == 0)
					throw new ArgumentException("InterfaceName must be longer then 0 characters.");

				// Set the value to null if the name of the interface is the same as the one of the persistent.
				if (value == string.Format(INTERFACE_NAME_TEMPLATE, _table.PersistentName))
					value = null;

				_interfaceName = value;
			}
		}

		#region IGeneratedObject Members

		/// <summary>
		/// Returns the ID of the object. This is a unique identifier that
		/// is required for synchronization with the display.
		/// </summary>
		public string ID
		{
			get { return _id; }
		}

		/// <summary>
		/// Returns the name of the object. Is displayed in the list when generating
		/// the objects.
		/// </summary>
		public string Name
		{
			get { return this.InterfaceName; }
		}

		#endregion
	}
}
