#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Text.RegularExpressions;
using Chili.Opf3.Wizard.CSharp.Properties;

#endregion

namespace Chili.Opf3.Wizard.CSharp.InterfacesProvider.UI
{
	/// <summary>
	/// This dialog allows to edit an interface.
	/// </summary>
	public partial class InterfaceDialog : Form
	{
		private Interface _interface;

		/// <summary>
		/// Creates a new instance of the <see cref="InterfaceDialog">InterfaceDialog Class</see>.
		/// </summary>
		/// <param name="i"></param>
		public InterfaceDialog(Interface i)
		{
			InitializeComponent();

			if (i == null)
				throw new ArgumentNullException("i", "Interface is null");
			_interface = i;

			this.Text = string.Format(Resources.EditInterfaceDialogTitle, i.InterfaceName);

			// Populates the controls.
			PopulateControls();
		}

		/// <summary>
		/// Populates the UI controls with data.
		/// </summary>
		private void PopulateControls()
		{
			persistentLabel.Text = _interface.Table.PersistentName;
			interfaceNameTextBox.Text = _interface.InterfaceName;
		}

		/// <summary>
		/// Invoked each time the form is about to close.
		/// </summary>
		private void InterfaceDialog_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (this.DialogResult != DialogResult.OK)
				return;

			e.Cancel = (!PopulateObject());
		}

		/// <summary>
		/// Populates the object with data.
		/// </summary>
		private bool PopulateObject()
		{
			if (interfaceNameTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.MissingInterfaceNameText, InterfacesProvider.Current.Name, MessageBoxButtons.OK,
					MessageBoxIcon.Error);
				return false;
			}

			_interface.InterfaceName = interfaceNameTextBox.Text;
			return true;
		}
	}
}