#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared;

#endregion
namespace Chili.Opf3.Wizard.CSharp.PersistentProvider
{
    /// <summary>
    /// This class represents one persistent that is created from a table.
    /// </summary>
    class Persistent : IGeneratedObject
    {
        private Table _table;
		private string _id = Guid.NewGuid().ToString();

        /// <summary>
        /// Creates a new instance of the <see cref="Persistent">Persistent Class</see>.
		/// </summary>
        /// <param name="table">The table associated with the Persistent.</param>
        public Persistent(Table table)
		{
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");

			_table = table;
		}

		/// <summary>
		/// Specifies the table associated with the interface.
		/// </summary>
		public Table Table
		{
			get { return _table; }
		}

        /// <summary>
        /// Specifies whether the persistent is generated.
        /// </summary>
        public bool Generate
        {
            get { return _table.Generate; }
            set { _table.Generate = value; }
        }

        #region IGeneratedObject Members

		/// <summary>
		/// Returns the ID of the object. This is a unique identifier that is required for synchronization with the display.
		/// </summary>
		public string ID
		{
			get { return _id; }
		}

		/// <summary>
		/// Returns the name of the object. Is displayed in the list when generating the objects.
		/// </summary>
		public string Name
        {
            get { return _table.PersistentName; }
        }

        #endregion
    }
}
