#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;

#endregion

namespace Chili.Opf3.Wizard.CSharp.PersistentProvider
{
	/// <summary>
	/// Creates the partial empty persistent object.
	/// </summary>
	public sealed class PersistentUserCreator
	{
		public const string OPENING_BRACKETS = "{";
		public const string CLOSING_BRACKETS = "}";

		private Template _template;
		private Project _project;
		private Table _table;

		/// <summary>
		/// Creates a new instance of the <see cref="PersistentGeneratedCreator">PersistentGeneratedCreator Class</see>.
		/// </summary>
		/// <param name="template">The template for the persistent creator.</param>
		/// <param name="project">The project of the wizard.</param>
		/// <param name="table">The current table that should be converted to a persistent.</param>
		public PersistentUserCreator(Project project, Table table, Template template)
		{
			if (template == null)
				throw new ArgumentNullException("template", "Template is null.");
			if (project == null)
				throw new ArgumentNullException("project", "Project is null.");
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");

			_template = template;
			_project = project;
			_table = table;
		}

		/// <summary>
		/// Returns the persistent object's file content.
		/// </summary>
		public string GetPersistent()
		{
			// Get the persistentGenerated template.
			string persistentGenerated = _template.GetValue("//persistentUser");

			// Return the compiled template.
			return string.Format(persistentGenerated, _table.PersistentName, _project.AutorInfo.Name, _project.AutorInfo.Copyright,
				DateTime.Now.ToShortDateString(), _project.Namespace, OPENING_BRACKETS, _table.TableName, 
				_table.PersistentName, OPENING_BRACKETS, CLOSING_BRACKETS, CLOSING_BRACKETS);
		}
	}
}
