#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.CSharp.Properties;
using Chili.Opf3.Wizard.Shared.UI;

#endregion

namespace Chili.Opf3.Wizard.CSharp.PersistentProvider.UI
{
	/// <summary>
	/// This class allows to customize the interfaces created by the 
	/// <see cref="CSharpPersistentInterfacesProvider">CSharpPersistentInterfacesProvider</see>.
	/// </summary>
	public partial class AdditionalDataPage : Page
	{
		private Project _project;
        private StateBag _statebag;

		/// <summary>
		/// Creates a new instance of the <see cref="InterfacePage">InterfacePage Class</see>.
		/// </summary>
		/// <param name="provider">The provider itself.</param>
        public AdditionalDataPage(PersistentProvider provider, StateBag statebag)
            : base(provider)
		{
			InitializeComponent();
            _statebag = statebag;
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		/// <param name="project">The current project.</param>
		public override void PageOpening(Project project)
		{
			// Set the current project.
			_project = project;

			SetHeaderTitle(Resources.AdditionalDataPageHeaderTitle);
			SetHeaderDescription(Resources.AdditionalDataPageHeaderDescription);

			partialGeneratedCheckBox.Checked = _statebag.CreateGenerated;
			sealedCheckBox.Checked = _statebag.PersistentSealed;
			virtualCheckBox.Checked = _statebag.PersistentPropertiesVirtual;
            usingDirectiveTextBox.Text = _statebag.AdditionalUsingDirective;
            baseclassTextBox.Text = _statebag.BaseClass;
			noEmptySilblingCheckBox.Checked = !_statebag.CreateEmptySilbing;
		}

		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
            _statebag.CreateGenerated = partialGeneratedCheckBox.Checked;
            _statebag.PersistentSealed = sealedCheckBox.Checked;
            _statebag.AdditionalUsingDirective = usingDirectiveTextBox.Text;
            _statebag.BaseClass = baseclassTextBox.Text;

            if (!sealedCheckBox.Checked)
            {
                _statebag.PersistentPropertiesVirtual = virtualCheckBox.Checked;
                _statebag.CreateGenerated = partialGeneratedCheckBox.Checked;
				_statebag.CreateEmptySilbing = !noEmptySilblingCheckBox.Checked;
            }
            else
            {
                _statebag.PersistentPropertiesVirtual = false;
                _statebag.CreateGenerated = false;
				_statebag.CreateEmptySilbing = false;
            }

			return true;
		}

        /// <summary>
        /// Invoked each time the checked state of the sealed check box changed.
        /// </summary>
        private void sealedCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            virtualCheckBox.Enabled = !sealedCheckBox.Checked;
            partialGeneratedCheckBox.Enabled = !sealedCheckBox.Checked;
			noEmptySilblingCheckBox.Enabled = !sealedCheckBox.Checked;
        }

		/// <summary>
		/// Invoked each time the partial generated check box's checked state is changed.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void partialGeneratedCheckBox_CheckedChanged(object sender, EventArgs e)
		{
			noEmptySilblingCheckBox.Enabled = partialGeneratedCheckBox.Checked;
		}
	}
}
