#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;

#endregion

namespace Chili.Opf3.Wizard.Shared
{
	/// <summary>
	/// EventsArgs for the GeneratedPersistentObject event fired by classes implementing 
	/// the <see cref="IPersistentObjectsProvider">IPersistentObjectsProvider</see> and 
	/// <see cref="IObjectsProvider">IObjectsProvider</see> interfaces.
	/// </summary>
	public sealed class GeneratedObjectEventArgs : EventArgs
	{
		private bool _success;
		private string _objectID;
		private Exception _exception;

		/// <summary>
		/// Creates a new instance of the <see cref="GeneratedObjectEventArgs">GeneratedObjectEventArgs Class</see>.
		/// </summary>
		/// <param name="objectID">The identifier of the object.</param>
		public GeneratedObjectEventArgs(string objectID)
		{
			if (objectID == null)
				throw new ArgumentNullException("objectID", "ObjectID is null.");

			_objectID = objectID;
			_success = true;
		}

		/// <summary>
		/// Creates a new instance of the <see cref="GeneratedObjectEventArgs">GeneratedObjectEventArgs Class</see>.
		/// </summary>
		/// <param name="objectID">The identifier of the object.</param>
		/// <param name="exception">The exception happened.</param>
		public GeneratedObjectEventArgs(string objectID, Exception exception) : this(objectID)
		{
			if (exception == null)
				throw new ArgumentNullException("exception", "Exception is null.");

			_success = false;
			_exception = exception;
		}

		/// <summary>
		/// Returns the identifier of the object.
		/// </summary>
		public string ObjectID
		{
			get { return _objectID; }
		}

		/// <summary>
		/// Returns whether the persistent was generated successfully.
		/// </summary>
		public bool Success
		{
			get { return _success; }
		}

		/// <summary>
		/// Returns the exception if the persistent was not created successfully. Or null if no error has happened.
		/// </summary>
		public Exception Exception
		{
			get { return _exception; }
		}
	}
}
