#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;

#endregion

namespace Chili.Opf3.Wizard.Shared
{
	/// <summary>
	/// EventsArgs for the GeneratingPersistentObject event fired by classes implementing 
	/// the <see cref="IPersistentObjectsProvider">IPersistentObjectsProvider</see> and 
	/// <see cref="IObjectsProvider">IObjectsProvider</see> interfaces.
	/// </summary>
	public sealed class GeneratingObjectEventArgs : EventArgs
	{
		private bool _cancel;
		private string _objectID;

		/// <summary>
		/// Creates a new instance of the <see cref="GeneratingObjectEventArgs">GeneratingObjectEventArgs Class</see>.
		/// </summary>
		/// <param name="objectID">The identifier of the object.</param>
		public GeneratingObjectEventArgs(string objectID)
		{
			if (objectID == null)
				throw new ArgumentNullException("objectID", "ObjectID is null.");

			_objectID = objectID;
		}

		/// <summary>
		/// Returns the idnetifier of the object.
		/// </summary>
		public string ObjectID
		{
			get { return _objectID; }
		}

		/// <summary>
		/// Specifies whether to cancel the creation of the current persistent object.
		/// </summary>
		public bool Cancel
		{
			get { return _cancel; }
			set { _cancel = value; }
		}
	}
}
