#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;

using Chili.Opf3.Wizard.Shared.UI;

#endregion

namespace Chili.Opf3.Wizard.Shared
{
	/// <summary>
	/// This interface is implemented by plug-ins that create objects as output of the tool.
	/// </summary>
	public interface IObjectsProvider
	{
		/// <summary>
		/// Generates the objects form the project structure.
		/// </summary>
		/// <param name="project">The project containing all selected tables and fields of the database.</param>
		void GenerateObjects(Project project);

		/// <summary>
		/// Event is fired before the object is generated from the data of the <see cref="Project">Project</see> class.
		/// </summary>
		event EventHandler<GeneratingObjectEventArgs> GeneratingObject;

		/// <summary>
		/// Event is fired after the object is generated from the data of the <see cref="Project">Project</see> class.
		/// </summary>
		event EventHandler<GeneratedObjectEventArgs> GeneratedObject;

		/// <summary>
		/// Returns the name for the plug-in.
		/// </summary>
		string Name
		{
			get;
		}

		/// <summary>
		/// Returns the description for the plug-in.
		/// </summary>
		string Description
		{
			get;
		}

        /// <summary>
        /// Returns the version of the plug-in.
        /// </summary>
        string Version
        {
            get;
        }

        /// <summary>
        /// Display the about dialog for the plug-in.
        /// </summary>
        void ShowAboutDialog();

        /// <summary>
        /// Deserialize the plug-in state from xml.
        /// </summary>
        /// <param name="project">The project.</param>
        /// <param name="xml">Specifies the xml document that holds the current project.</param>
        /// <param name="d">The node holding the data for the provider.</param>
        void Deserialize(Project project, XmlDocument xml, XmlNode d);

        /// <summary>
        /// Tell the plug-in to initialize defaults in a new project.
        /// </summary>
        /// <param name="project">The project.</param>
        void InitializeDefaults(Project project);

        /// <summary>
        /// Serialize the plug-in state in xml.
        /// </summary>
        /// <param name="project">The project.</param>
        /// <param name="xml">Specifies the current xml document that is created for the project.</param>
        /// <param name="d">The node where the provider should serialize its data to.</param>
        void Serialize(Project project, XmlDocument xml, XmlNode d);

        /// <summary>
        /// Allow the provider to build its internal data from storage's returned data.
        /// </summary>
        /// <param name="project">The current project.</param>
        void ProcessStorage(Project project);

		/// <summary>
		/// Returns a list of pages displayed by the class.
		/// </summary>
		List<Page> Pages
		{
			get;
		}

		/// <summary>
		/// Gets the language name supported by this tool. Or null if no explicit language
		/// is supported.
		/// </summary>
		string LanguageName
		{
			get;
		}

		/// <summary>
		/// Returns the list of objects that are generated.
		/// </summary>
		List<IGeneratedObject> GetObjectsList();
	}
}
