#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Serialization;
using Chili.Opf3.Wizard.Shared.Storages;
using System.Text.RegularExpressions;

#endregion

namespace Chili.Opf3.Wizard.Shared
{
	/// <summary>
	/// This class represents one project created during executing the wizard and 
	/// selecting tables and fields.
	/// </summary>
	public sealed class Project 
	{
		private Storage _storage;
		private string _outputDirectory;
		private List<Table> _tables = new List<Table>();
		private List<Relation> _relations = new List<Relation>();
		private string _namespace;
		private AutorInfo _autorInfo = new AutorInfo();
		private bool _renameItemsToSingular = true;
		private StorageSchema _storageSchema;
        private TypeConverter _typeconverter = new TypeConverter();
        private int _removefirstchars=0;

		/// <summary>
		/// Returns the information about the autor.
		/// </summary>
		public AutorInfo AutorInfo
		{
            get { return _autorInfo; }
		}

		/// <summary>
		/// Specifies the storage of the project.
		/// </summary>
		public Storage Storage
		{
			get { return _storage; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("storag", "Storage is null.");

				_storage = value;
			}
		}

		/// <summary>
		/// Specifies the output directory of the project.
		/// </summary>
		public string OutputDirectoy
		{
			get { return _outputDirectory; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("outputDirectory", "OutputDirectory is null.");
 
				_outputDirectory = value; 
			}
		}

		/// <summary>
		/// Specifies the namespace of the project.
		/// </summary>
		public string Namespace
		{
			get { return _namespace; }
			set
			{
				if (value == null)
					throw new ArgumentNullException("namespace", "Namespace is null.");
				if (value.Trim().Length == 0)
					throw new ArgumentException("Namespace is 0 characters long. Not allowed.");

				_namespace = value;
			}
		}

		/// <summary>
		/// Specifies whether the items are renamed to singular.
		/// </summary>
		public bool RenameItemsToSingular
		{
			get { return _renameItemsToSingular; }
			set { _renameItemsToSingular = value; }
		}

        /// <summary>
        /// Specifies whether the field name is truncate left by the amount.
        /// </summary>
        public int RemoveFirstChars
        {
            get { return _removefirstchars; }
            set { _removefirstchars = value; }
        }

		/// <summary>
		/// Specifies the tables that are used to create the persistent objects.
		/// </summary>
		public List<Table> Tables
		{
			get { return _tables; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("tables", "Tables is null.");

				_tables = value; 
			}
		}

		/// <summary>
		/// Specifies the relations between the database's tables.
		/// </summary>
		public List<Relation> Relations
		{
			get { return _relations; }
			set
			{
				if (value == null)
					throw new ArgumentNullException("relations", "Relations is null.");

				_relations = value;
			}
        }

        /// <summary>
        /// Returt the typeconverter helper.
        /// </summary>
        public TypeConverter TypeConverter
        {
            get { return _typeconverter; }   
        }

        #region Utility methods

        /// <summary>
        /// Retrieve a table from storage given its name.
        /// </summary>
        public Table GetTableByName(string tablename)
        {
            foreach (Table table in this.Tables)
            {
                if (table.TableName == tablename)
                    return table;
            }
            return null;
        }

        /// <summary>
        /// Retrieve a field from storage given its name and its tablename.
        /// </summary>
        public Field GetFieldByName(string tablename, string fieldname)
        {
            Table table = GetTableByName(tablename);
            if (table != null)
            {
                foreach (Field field in table.Fields)
                {
                    if (field.FieldName == fieldname)
                        return field;
                }
            }
            return null;
        }
        #endregion

        /// <summary>
		/// Specifies the last retrieved storage schema.
		/// </summary>
		public StorageSchema LastRetrievedStorageSchema
		{
			get { return _storageSchema; }
			set { _storageSchema = value; }
		}        
    }
}
