#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Text.RegularExpressions;
using System.Xml.Serialization;

#endregion

namespace Chili.Opf3.Wizard.Shared.Storages
{
	/// <summary>
	/// Represents one field of the datatable.
	/// </summary>
    [Serializable]
	public sealed class Field
	{
		private string _fieldName;
		private string _objFieldName;
		private string _propertyName;
		private bool _allowDBNull = true;
		private bool _identifier;
		private bool _autonumber;
		private Type _type;
		private bool _generate = true;
		private int _length = -1;
        private string _description;
		private PersistBehaviours _persistBehaviour = PersistBehaviours.None;

        /// <summary>
        /// Field constructor.
        /// </summary>
        public Field()
        {
        }

		/// <summary>
		/// Returns the name of the storage field.
		/// </summary>
		public string FieldName
		{
			get { return _fieldName; }
			set
			{
				if (value == null)
					throw new ArgumentNullException("value", "FieldName is null.");
				if (value.Length == 0)
					throw new ArgumentException("FieldName is 0 characters long. Not allowed.");

				_fieldName = value;
			}
		}

		/// <summary>
		/// Specifies the name of the persistent field.
		/// </summary>
		public string ObjectFieldName
		{
			get { return _objFieldName; }
			set
			{
				if (value == null)
					throw new ArgumentNullException("objectFieldName", "ObjectFieldName is null.");
				if (value.Length == 0)
					throw new ArgumentException("ObjectFieldName is 0 characters long. Not allowed.");

				_objFieldName = value;
			}
		}

		/// <summary>
		/// Specifies the name of the persistent property.
		/// </summary>
		public string PropertyName
		{
			get { return _propertyName; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("propertyName", "PropertyName is null.");
				if (value.Length == 0)
					throw new ArgumentException("PropertyName is 0 characters long. Not allowed.");

				_propertyName = value; 
			}
		}

		/// <summary>
		/// Specifies whether null is allowed for this field.
		/// </summary>
		public bool AllowDBNull
		{
			get { return _allowDBNull; }
			set { _allowDBNull = value; }
		}

		/// <summary>
		/// Specifies whether the field is a primary key of the datatable.
		/// </summary>
		public bool Identifier
		{
			get { return _identifier; }
			set { _identifier = value; }
		}

		/// <summary>
		/// Specifies whether the field is an autoincrement.
		/// </summary>
		public bool AutoNumber
		{
			get { return _autonumber; }
			set { _autonumber = value; }
		}

		/// <summary>
		/// Specifies the type of the field.
		/// </summary>
		public Type Type
		{
			get { return _type; }
			set { _type = value; }
        }

        /// <summary>
        /// Specifies the description of the fields (comments).
        /// </summary>
        public string Description
        {
            get { return _description; }
            set { _description = value; }
        }


        /// <summary>
		/// Specifies whether the field is generated as property of the persistent object.
		/// </summary>
		public bool Generate
		{
			get { return _generate; }
			set { _generate = value; }
		}

		/// <summary>
		/// Specifies the length of the field.
		/// </summary>
		public int Length
		{
			get { return _length; }
			set { _length = value; }
		}

		/// <summary>
		/// Specifies the persist behaviour of the field.
		/// </summary>
		public PersistBehaviours PersistBehaviour
		{
			get { return _persistBehaviour; }
			set { _persistBehaviour = value; }
		}

        /// <summary>
        /// override default to string, return PropertyName.
        /// </summary>
        public override string ToString()
        {
            return _propertyName;
        }

        /// <summary>
        /// Returns whether the field is nullable.
        /// </summary>
        public bool IsNullable
        {
            get { return (this.Type != typeof(string) && this.Type != typeof(byte[]) && this.AllowDBNull && !this.Identifier); }
        }
	}
}
