#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;

#endregion

namespace Chili.Opf3.Wizard
{
	/// <summary>
	/// This utility generates names for the objects.
	/// </summary>
	public static class NameUtility
	{
		private const string IES = "ies";
		private const string S = "s";
		private const string ADDRESSES = "Addresses";
		private const string NEWS = "News";

		/// <summary>
		/// Returns the name for the property.
		/// </summary>
		/// <param name="columnName">The column of the table.</param>
		public static string GetPropertyName(string columnName)
		{
			return GetItemName(columnName);
		}

		/// <summary>
		/// Returns the name of the persistent.
		/// </summary>
		/// <param name="entityName">The name of the storage entity.</param>
		/// <param name="singleCase">True to return the name in single case.</param>
		public static string GetPersistentName(string entityName, bool singleCase)
		{
			string result = GetItemName(entityName);
			if (singleCase)
				return ConvertToSingleCase(result);
			return result;
		}

		/// <summary>
		/// Returns the object field name. The object field name is created form the property name.
		/// </summary>
		/// <param name="columnName">The column of the table.</param>
		public static string GetObjectFieldName(string columnName)
		{
			string itemName = GetItemName(columnName);
			if (itemName.Length <= 2)
				return itemName.ToLower();
			return string.Format("{0}{1}", itemName[0].ToString().ToLower(), itemName.Substring(1));
		}

		/// <summary>
		/// Tries to convert the object name to single case.
		/// </summary>
		/// <param name="objectName">The name of the object.</param>
		private static string ConvertToSingleCase(string objectName)
		{
			if (objectName == ADDRESSES)
				return objectName.Substring(0, objectName.Length - 2);
			if (objectName == NEWS)
				return objectName;
			else if (objectName.EndsWith(IES))
				return objectName.Substring(0, objectName.Length - IES.Length) + "y";
			else if (objectName.EndsWith(S))
				return objectName.Substring(0, objectName.Length - S.Length);
			return objectName;
		}

		#region GetItemName

		/// <summary>
		/// Returns the name for the item.
		/// </summary>
		/// <param name="itemName">The name of the item.</param>
		private static string GetItemName(string itemName)
		{
			if (itemName == null)
				throw new ArgumentNullException("itemName", "ItemName is null.");
			if (itemName.Length == 0)
				throw new ArgumentException("ItemName is 0 characters long. Not allowed.");

			// If the itemName is not upper or lower return immediately.
			if (itemName.ToUpper() != itemName && itemName.ToLower() != itemName)
			{
				// Return the item name, but replace all spaces.
				return itemName.Replace(" ", "");
			}
			// Items with length 2 are not processed.
			if (itemName.Length == 2)
				return itemName;

			string parsedName = string.Empty;
			// Loop over the name.
			for (int i = 0; i < itemName.Length; i++)
			{
				char c = itemName[i];

				if (c == '_' || c == ' ')
				{
					i++;
					if (i >= itemName.Length)
						break;

					// If we are at the end and there are two characters left make them upper case.
					if ((i + 2) == itemName.Length)
					{
						parsedName += itemName.Substring(i, 2).ToUpper();
						i += 2;
					}
					else
					{
						// Upper after underscores.
						parsedName += itemName[i].ToString().ToUpper();
					}
				}
				else if (i == 0)
				{
					// Upper the first char.
					parsedName += c.ToString().ToUpper();
				}
				else
				{
					// Lower the rest.
					parsedName += c.ToString().ToLower();
				}
			}
			return parsedName;
		}

		#endregion
	}
}
