#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Text.RegularExpressions;

#endregion

namespace Chili.Opf3.Wizard.Shared.Storages
{
	/// <summary>
	/// This class represents a relation between two tables.
	/// </summary>
	public sealed class Relation
	{
        private string _name;
		private Table _parentTable;
		private Table _childTable;
		private Table _weakTable;
		private RelationTypes _relationType = RelationTypes.OneToMany;
		private List<RelationItem> _relations = new List<RelationItem>();
		private List<RelationItem> _weakRelations = new List<RelationItem>();
		private bool _createInParentPersistent = true;
		private bool _createInChildPersistent = true;
		private string _childProperty;
		private string _parentProperty;
		private bool _generate = true;
		private PersistBehaviours _persistBehaviour = PersistBehaviours.None;

		/// <summary>
		/// Returns the relation name.
		/// </summary>
		public string Name
		{
			get { return _name; }
			set { _name = value; }
		}

        /// <summary>
        /// Returns the parent table (the table containing the primary keys).
        /// </summary>
        public Table ParentTable
        {
            get { return _parentTable; }
            set
            {
                if (value == null)
                    throw new ArgumentNullException("ParentTable", "Value is null.");

                _parentTable = value;
            }
        }

		/// <summary>
		/// Returns the child table (the table containing the foreign keys).
		/// </summary>
		public Table ChildTable
		{
			get { return _childTable; }
			set 
			{
				if (value == null)
                    throw new ArgumentNullException("ChildTable", "Value is null.");

				_childTable = value; 
			}
		}

		/// <summary>
		/// Returns the weak table (aka weak entity).
		/// </summary>
		public Table WeakTable
		{
			get { return _weakTable; }
			set { _weakTable = value; }
		}

		/// <summary>
		/// Specifies the type of the relation.
		/// </summary>
		public RelationTypes RelationType
		{
			get { return _relationType; }
			set { _relationType = value; }
		}

		/// <summary>
		/// Specifies whether the relation is created also for the parent persistent object.
		/// </summary>
		public bool CreateInParentPersistent
		{
			get { return _createInParentPersistent; }
			set { _createInParentPersistent = value; }
		}

		/// <summary>
		/// Specifies whether the relation is created also for the child persistent object.
		/// </summary>
		public bool CreateInChildPersistent
		{
			get { return _createInChildPersistent; }
			set { _createInChildPersistent = value; }
		}

		/// <summary>
		/// Specifies the relations.
		/// </summary>
		public List<RelationItem> Relations
		{
			get { return _relations; }
		}

		/// <summary>
		/// Specifies the weak relations.
		/// </summary>
		public List<RelationItem> WeakRelations
		{
			get { return _weakRelations; }
		}

		/// <summary>
		/// Specifies the relation property in the parent object.
		/// </summary>
		public string ParentProperty
		{
			get { return _parentProperty; }
			set { _parentProperty = value; }
		}

		/// <summary>
		/// Specifies the relation property in the child object.
		/// </summary>
		public string ChildProperty
		{
			get { return _childProperty; }
			set { _childProperty = value; }
		}

		/// <summary>
		/// Specifies whether the relation is generated as property of the persistent object.
		/// </summary>
		public bool Generate
		{
			get { return _generate; }
			set { _generate = value; }
		}

		/// <summary>
		/// Specifies the persist behaviour of the relation.
		/// </summary>
		public PersistBehaviours PersistBehaviour
		{
			get { return _persistBehaviour; }
			set { _persistBehaviour = value; }
		}
	}
}
