#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Data.OleDb;
using System.Collections.Generic;

#endregion

namespace Chili.Opf3.Wizard.Shared.Storages
{
	/// <summary>
	/// Represents an storage.
	/// </summary>
	public sealed class Storage
	{
		private string _alias;
		private string _connectionString;

		/// <summary>
		/// Creates a new instance of the storage class.
		/// </summary>
		/// <param name="alias">The alias of the storage.</param>
		/// <param name="connectionString">The connection object for the storage.</param>
		public Storage(string alias, string connectionString)
		{
			if (connectionString == null)
				throw new ArgumentNullException("connectionString", "ConnectionString is null.");
			if (alias == null)
				throw new ArgumentNullException("alias", "Alias is null.");
			if (alias.Length == 0)
				throw new ArgumentException("Alias is 0 characters long. Not allowed.");

			_alias = alias;
			_connectionString = connectionString;
		}

		/// <summary>
		/// Specifies the alias of the storage.
		/// </summary>
		public string Alias
		{
			get { return _alias; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("value", "Alias is null.");
				if (value.Length == 0)
					throw new ArgumentException("Alias is 0 characters long. Not allowed.");

				_alias = value; 
			}
		}

		/// <summary>
		/// Specifies the connection string.
		/// </summary>
		public string ConnectionString
		{
			get { return _connectionString; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("value", "ConnectionString is null.");

				_connectionString = value; 
			}
		}
	}
}
