#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Text.RegularExpressions;
using System.Xml.Serialization;

#endregion

namespace Chili.Opf3.Wizard.Shared.Storages
{
	/// <summary>
	/// Represents one table of the database.
	/// </summary>
	public sealed class Table
	{
		private string _tableName;
		private string _persistentName;
        private string _baseclass;
		private int _poolSize = -1;
		private bool _noPool = true;
		private PersistentRights _rights = PersistentRights.All;
		private List<Field> _fields = new List<Field>();
        private List<Index> _indexes = new List<Index>();
		private bool _generate = true;
        private bool _isview = false;

		/// <summary>
		/// Returns a string representation of the object.
		/// </summary>
		/// <returns></returns>
		public override string ToString()
		{
			return _tableName;
		}

		/// <summary>
		/// Returns the name of the table.
		/// </summary>
		public string TableName
		{
			get { return _tableName; }
			set 
			{
				if (value == null)
					throw new ArgumentNullException("value", "TableName is null.");
				if (value.Length == 0)
					throw new ArgumentException("Tablename is 0 characters long. Not allowed.");

				_tableName = value; 
			}
		}

		/// <summary>
		/// Specifies the name of the persistent.
		/// </summary>
		public string PersistentName
		{
			get { return _persistentName; }
			set
			{
				if (value == null)
					throw new ArgumentNullException("persistentName", "PersistentName is null.");
				if (value.Length == 0)
					throw new ArgumentException("PersistentName is 0 characters long. Not allowed.");

				_persistentName = value;
			}
		}

        /// <summary>
        /// Specifies an optional base class.
        /// </summary>
        public string BaseClass
        {
            get { return _baseclass; }
            set { _baseclass=value; }
        }

		/// <summary>
		/// Specifies the size of the pool.
		/// </summary>
		public int PoolSize
		{
			get { return _poolSize; }
			set { _poolSize = value; }
		}

		/// <summary>
		/// True if no pool is allociated for the persistent object.
		/// </summary>
		public bool NoPool
		{
			get { return _noPool; }
			set { _noPool = value; }
		}

		/// <summary>
		/// Specifies the rights of the persistent object.
		/// </summary>
		public PersistentRights Rights
		{
			get { return _rights; }
			set { _rights = value; }
		}

		/// <summary>
		/// Specifies the fields of the table.
		/// </summary>
		public List<Field> Fields
		{
			get { return _fields; }
		}

        /// <summary>
        /// Specifies the index of the table.
        /// </summary>
        public List<Index> Indexes
        {
            get { return _indexes; }
        }

		/// <summary>
		/// Specifies whether the table is generated as persistent object.
		/// </summary>
		public bool Generate
		{
			get { return _generate; }
			set { _generate = value; }
		}

        /// <summary>
        /// Specifies whether the table is a view.
        /// </summary>
        public bool IsView
        {
            get { return _isview; }
            set { _isview = value; }
        }
	}
}
