#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.IO;

#endregion

namespace Chili.Opf3.Wizard.Shared
{
	/// <summary>
	/// This class represents the template that is used to generate the persistent object.
	/// </summary>
	public sealed class Template
	{
		XmlDocument _xml;

		/// <summary>
		/// Creates a new instance of the <see cref="Template">Template Class</see>.
		/// </summary>
		/// <param name="path">Path of the template.</param>
		public Template(string path)
		{
			if (path == null)
				throw new ArgumentNullException("path", "Path is null.");
			// Check if the file exists.
			if (!File.Exists(path))
				throw new FileNotFoundException("File for the template does not exist.");

			_xml = new XmlDocument();
			_xml.Load(path);
		}

		/// <summary>
		/// Returns the value at the given xpath epression.
		/// </summary>
		/// <param name="xpath">The xpath expression to get the value.</param>
		public string GetValue(string xpath)
		{
			XmlNodeList nodes = _xml.SelectNodes(xpath);

			if (nodes.Count == 0)
				throw new InvalidOperationException(string.Format("Node '{0}' not found.", xpath));
			if (nodes.Count > 1)
				throw new InvalidOperationException("More then one node found.");

			return nodes[0].InnerText;
		}

        /// <summary>
        /// Returns the the xmldocument witch template is based on.
        /// </summary>
        public XmlDocument Document
        {
            get { return _xml; }
        }
	}
}
