#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives
using System;
using System.Collections.Generic;
using System.Text;
#endregion

namespace Chili.Opf3.Wizard.Shared
{
    /// <summary>
    /// Represents a conversion pair basetype conversiontype.
    /// </summary>
    public class TypeConversionPair
    {
        private string _namecondition;
        private string _language;
        private string _initializer;
        private string _targettype;
        private string _basetype;
        private bool _ignorecase = true;

        /// <summary>
        /// Creates a new instance of the <see cref="TypeConversionPair">TypeConversionPair Class</see>.
        /// </summary>
        public TypeConversionPair()
        {
        }

        /// <summary>
        /// Creates a new instance of the <see cref="TypeConversionPair">TypeConversionPair Class</see>.
        /// </summary>
        /// <param name="basetype">The basetype for the TypeConversionPair creator.</param>
        /// <param name="targettype">The targettype for the TypeConversionPair creator.</param>
        public TypeConversionPair(string basetype, string targettype) : this()
        {
            _basetype = basetype;
            _targettype = targettype;
        }

        /// <summary>
        /// Specifies the name of the Language of TypeConversionPair.
        /// </summary>
        public string Language
        {
            get { return _language; }
            set { _language = value; }
        }

        /// <summary>
        /// Specifies the name of the BaseType of TypeConversionPair.
        /// </summary>
        public string BaseType
        {
            get { return _basetype; }
            set { _basetype = value; }
        }

        /// <summary>
        /// Specifies the name of the TargetType of TypeConversionPair.
        /// </summary>
        public string TargetType
        {
            get { return _targettype; }
            set { _targettype = value; }
        }

        /// <summary>
        /// Specifies the name of the Initializer of TypeConversionPair.
        /// </summary>
        public string Initializer
        {
            get { return _initializer; }
            set { _initializer = value; }
        }

        /// <summary>
        /// Specifies the name of the NameCondition of TypeConversionPair.
        /// </summary>
        public string NameCondition
        {
            get { return _namecondition; }
            set { _namecondition = value; }
        }

        /// <summary>
        /// Specifies if to ignore case matching NameCondition.
        /// </summary>
        public bool IgnoreCase
        {
            get { return _ignorecase; }
            set { _ignorecase = value; }
        }

        /// <summary>
        /// Compare return true if all properties matches.
        /// </summary>
        /// <param name="pair">The pair for the TypeConversionPair creator.</param>
        public bool Compare(TypeConversionPair pair)
        {
            if (_language != pair.Language) return false;
            if (_basetype != pair.BaseType) return false;
            if (_targettype != pair.TargetType) return false;
            if ((_initializer != null) && (_initializer != pair.Initializer)) return false;
            if ((_namecondition != null) && (_namecondition != pair.NameCondition)) return false;
            if (_ignorecase != pair.IgnoreCase) return false;

            return true;
        }

        /// <summary>
        /// Copy the values to te pair .
        /// </summary>
        public void CopyTo(TypeConversionPair pair)
        {
            pair.Language = this.Language;
            pair.BaseType = this.BaseType;
            pair.TargetType = this.TargetType;
            pair.Initializer = this.Initializer;
            pair.NameCondition = this.NameCondition;
            pair.IgnoreCase = this.IgnoreCase;
        }

    }
}
