#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

#endregion

namespace Chili.Opf3.Wizard.Shared.UI
{
	/// <summary>
	/// This class is a page that is used by a clas that implements the <see cref="IObjectsProvider">IObjectsProvider</see>
	/// interface to display a page in the wizard.
	/// </summary>
	public partial class Page : UserControl
	{
		private IObjectsProvider _provider;

		/// <summary>
		/// Creates a new instance of the <see cref="Page">Page Class</see>.
		/// </summary>
		private Page()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Creates a new instance of the <see cref="Page">Page Class</see>.
		/// </summary>
		/// <param name="provider">The provider that created this page.</param>
		public Page(IObjectsProvider provider) : this()
		{
			if (provider == null)
				throw new ArgumentNullException("provider", "Provider is null.");
			_provider = provider;
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		/// <param name="project">The current project.</param>
		public virtual void PageOpening(Project project)
		{
		}

		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public virtual bool PageClosing(bool next)
		{
			return true;
		}

		/// <summary>
		/// Specifies the title of the header.
		/// </summary>
		/// <param name="value">Value set as header title.</param>
		public void SetHeaderTitle(string value)
		{
			Control control = this.Parent;
			if (control != null)
				control.GetType().GetMethod("SetHeaderTitle").Invoke(control, new object[] { value });
		}

		/// <summary>
		/// Specifies the description of the header.
		/// </summary>
		/// <param name="value">Value set as header description.</param>
		public void SetHeaderDescription(string value)
		{
			Control control = this.Parent;
			if (control != null)
				control.GetType().GetMethod("SetHeaderDescription").Invoke(control, new object[] { value });
		}

		/// <summary>
		/// Returns the name of the provider that created this page.
		/// </summary>
		public IObjectsProvider Provider
		{
			get { return _provider; }
		}
	}
}
