#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;

#endregion

namespace Chili.Opf3.Wizard.VB.InterfacesProvider
{
	/// <summary>
	/// This class generates the interface for one persistent object.
	/// </summary>
	public sealed class InterfaceCreator
	{
		private Project _project;
		private Interface _interface;
		private Template _template;

		/// <summary>
		/// Creates a new instance of the <see cref="InterfaceCreator">InterfaceCreator Class</see>.
		/// </summary>
		/// <param name="template">The template for the persistent creator.</param>
		/// <param name="project">The project of the wizard.</param>
		/// <param name="table">The current table that should be converted to a persistent.</param>
		public InterfaceCreator(Project project, Interface iface, Template template)
		{
			if (template == null)
				throw new ArgumentNullException("template", "Template is null.");
			if (project == null)
				throw new ArgumentNullException("project", "Project is null.");
			if (iface == null)
				throw new ArgumentNullException("iface", "Interface is null.");

			_template = template;
			_project = project;
			_interface = iface;
		}

		/// <summary>
		/// Returns the interface ojbect.
		/// </summary>
		public string GetInterface()
		{
			string relations = new RelationsCreator(_project, _interface.Table, _template).CreateRelations();
			string properties = new PropertiesCreator(_project, _interface.Table, _template).CreateProperties();

			string body = string.Format("{0}{1}", relations, properties);

			// Return the compiled template.
			return string.Format(_template.GetValue("//interface"), _interface.InterfaceName, _project.AutorInfo.Name, 
				_project.AutorInfo.Copyright, DateTime.Now.ToString(), _interface.Table.PersistentName, _interface.InterfaceName, body);
		}

		#region GetVBType

		/// <summary>
		/// Returns the VB type for a given field.
		/// </summary>
		/// <param name="field">The field that's type is returned.</param>
		/// <param name="template">The template in use.</param>
		public static string GetVBType(Template template, Field field)
		{
			string type = template.GetValue(string.Format("//types/type[@id = '{0}']", field.Type));
			// Create the type as nullable type if not a string and null is allowed.
            if (IsNullable(field))
                type = String.Format("Nullable(Of {0})", type);
			return type;
		}

		/// <summary>
		/// Returns whether the field is nullable.
		/// </summary>
		/// <param name="field">Field that is checked.</param>
		public static bool IsNullable(Field field)
		{
			return (field.Type != typeof(string) && field.Type != typeof(byte[]) && field.AllowDBNull && !field.Identifier);
		}

		#endregion
	}
}
