#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.VB.Properties;

#endregion

namespace Chili.Opf3.Wizard.VB.PersistentProvider
{
	/// <summary>
	/// Creates the fields of the persistent object.
	/// </summary>
	public sealed class FieldsCreator
	{
		private Template _template;
		private Table _table;
        private Project _project;

		/// <summary>
		/// Creates a new instance of the <see cref="FieldsCreator">FieldsCreator Class</see>.
		/// </summary>
        /// <param name="project">The project of the wizard.</param>
		/// <param name="template">The template for the persistent creator.</param>
		/// <param name="table">The current table that should be converted to a persistent.</param>
        public FieldsCreator(Project project, Table table, Template template)
		{
            if (project == null)
                throw new ArgumentNullException("project", "Project is null.");
			if (template == null)
				throw new ArgumentNullException("template", "Template is null.");
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");

			_template = template;
			_table = table;
            _project = project;
		}

		/// <summary>
		/// Creates the fields of the persistent object.
		/// </summary>
		public string CreateFields()
		{
			string result = string.Empty;

			foreach (Field field in _table.Fields)
			{
				// Skip fields that are not generated.
				if (!field.Generate)
					continue;

				// Add a new line if we are in the >= second field.
				if (result.Length > 0)
					result += "\r\n";

                string initialize = _project.TypeConverter.GetTypeInitializer(Resources.LanguageName, field); 

				// Add the field to the result.
                result += string.Format(_template.GetValue("//properties/field"), _project.TypeConverter.GetFormattedType(Resources.LanguageName, field, "Nullable(Of {0})"), 
					field.ObjectFieldName, initialize);
			}

			return string.Format(_template.GetValue("//fieldRegion"), result);
		}
	}
}
