#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Serialization;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.VB.PersistentProvider
{
	/// <summary>
	/// This class holds the state of the plugin.
	/// </summary>
    [Serializable] 
	public sealed class StateBag
	{
		private bool _iDynamicExtensible;
		private bool _iObjectNotification;
		private bool _iPopulateHelper;
		private bool _iSelfContainingObject;
		private bool _iNotifyPropertyChanged;
        private bool _persistentPropertiesVirtual;
        private bool _persistentSealed;
        private bool _createGenerated;
        private string _additionalusingdirective;
        private string _baseclass;
		private bool _createEmptySilbling;

		/// <summary>
		/// Gets or sets whether the empty silbling should be generated.
		/// </summary>
		public bool CreateEmptySilbing
		{
			get { return _createEmptySilbling; }
			set { _createEmptySilbling = value; }
		}

		/// <summary>
		/// Specifies if the INotifyPropertyChanged interface is implemented.
		/// </summary>
		public bool INotifyPropertyChanged
		{
			get { return _iNotifyPropertyChanged; }
			set { _iNotifyPropertyChanged = value; }
		}

		/// <summary>
		/// Specifies if the IDynamicExtensible interface is implemented.
		/// </summary>
		public bool IDynamicExtensible
		{
			get { return _iDynamicExtensible; }
			set { _iDynamicExtensible = value; }
		}

		/// <summary>
		/// Specifies if the IObjectNotification interface is implemented.
		/// </summary>
		public bool IObjectNotification
		{
			get { return _iObjectNotification; }
			set { _iObjectNotification = value; }
		}

		/// <summary>
		/// Specifies if the IPopulateHelper interface is implemented.
		/// </summary>
		public bool IPopulateHelper
		{
			get { return _iPopulateHelper; }
			set { _iPopulateHelper = value; }
		}

		/// <summary>
		/// Specifies if the ISelfContainingObject interface is implemented.
		/// </summary>
		public bool ISelfContainingObject
		{
			get { return _iSelfContainingObject; }
			set { _iSelfContainingObject = value; }
		}

        /// <summary>
        /// True to have all persistent properties marked as virtual.
        /// </summary>
        public bool PersistentPropertiesVirtual
        {
            get { return _persistentPropertiesVirtual; }
            set { _persistentPropertiesVirtual = value; }
        }

        /// <summary>
        /// True to have all persistent marked as sealed.
        /// </summary>
        public bool PersistentSealed
        {
            get { return _persistentSealed; }
            set { _persistentSealed = value; }
        }

        /// <summary>
        /// Specifies whether the partial .generated class is created or not.
        /// </summary>
        public bool CreateGenerated
        {
            get { return _createGenerated; }
            set { _createGenerated = value; }
        }

        /// <summary>
        /// Specifies additional using directive.
        /// </summary>
        public string AdditionalUsingDirective
        {
            get { return _additionalusingdirective; }
            set { _additionalusingdirective = value; }
        }

        /// <summary>
        /// Specifies a base class for the persistent.
        /// </summary>
        public string BaseClass
        {
            get { return _baseclass; }
            set { _baseclass = value; }
        }

        /// <summary>
        /// Serialize the PersistentProviderStateBag state in xml.
        /// </summary>
        public XmlNode Serialize(XmlDocument xml)
        {
            XmlElement s = xml.CreateElement("statebag");
            s.AppendChild(CreateXmlElement(xml, "INotifyPropertyChanged", _iDynamicExtensible.ToString()));
            s.AppendChild(CreateXmlElement(xml, "IDynamicExtensible", _iObjectNotification.ToString()));
            s.AppendChild(CreateXmlElement(xml, "IObjectNotification", _iPopulateHelper.ToString()));
            s.AppendChild(CreateXmlElement(xml, "IPopulateHelper", _iSelfContainingObject.ToString()));
            s.AppendChild(CreateXmlElement(xml, "ISelfContainingObject", _iNotifyPropertyChanged.ToString()));
            s.AppendChild(CreateXmlElement(xml, "PersistentPropertiesVirtual", _persistentPropertiesVirtual.ToString()));
            s.AppendChild(CreateXmlElement(xml, "PersistentSealed", _persistentSealed.ToString()));
            s.AppendChild(CreateXmlElement(xml, "CreateGenerated", _createGenerated.ToString()));
            s.AppendChild(CreateXmlElement(xml, "AdditionalUsingDirective", _additionalusingdirective));
            s.AppendChild(CreateXmlElement(xml, "BaseClass", _baseclass));
			s.AppendChild(CreateXmlElement(xml, "CreateEmptySilbling", _createEmptySilbling.ToString()));
            return s;
        }

        /// <summary>
        /// Deserialize the PersistentProviderStateBag from xml.
        /// </summary>
        public void Deserialize(Project project, XmlDocument xml, XmlNode d)
        {
            XmlNode p = d.SelectSingleNode("./statebag");

            if (p != null)
            {
                try
                {
                    _iDynamicExtensible = bool.Parse(p.SelectSingleNode("./INotifyPropertyChanged").InnerText);
                    _iObjectNotification = bool.Parse(p.SelectSingleNode("./IDynamicExtensible").InnerText);
                    _iPopulateHelper = bool.Parse(p.SelectSingleNode("./IObjectNotification").InnerText);
                    _iSelfContainingObject = bool.Parse(p.SelectSingleNode("./IPopulateHelper").InnerText);
                    _iNotifyPropertyChanged = bool.Parse(p.SelectSingleNode("./ISelfContainingObject").InnerText);
                    _persistentPropertiesVirtual = bool.Parse(p.SelectSingleNode("./PersistentPropertiesVirtual").InnerText);
                    _persistentSealed = bool.Parse(p.SelectSingleNode("./PersistentSealed").InnerText);
                    _createGenerated = bool.Parse(p.SelectSingleNode("./CreateGenerated").InnerText);
                    _additionalusingdirective = p.SelectSingleNode("./AdditionalUsingDirective").InnerText;
                    _baseclass = p.SelectSingleNode("./BaseClass").InnerText;
					_createEmptySilbling = bool.Parse(p.SelectSingleNode("./CreateEmptySilbling").InnerText);
				}
                catch { }
            }
        }

        /// <summary>
        /// Creates an xml element with the given name and value.
        /// </summary>
        /// <param name="name">The name of the element.</param>
        /// <param name="value">The value of the element.</param>
        private XmlNode CreateXmlElement(XmlDocument xml, string name, string value)
        {
            XmlElement e = xml.CreateElement(name);
            e.AppendChild(xml.CreateTextNode(value));

            return e;
        }

	}
}
