#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.VB.Properties;
using Chili.Opf3.Wizard.Shared.UI;

#endregion

namespace Chili.Opf3.Wizard.VB.PersistentProvider.UI
{
	/// <summary>
	/// This class allows to customize the interfaces created by the 
	/// <see cref="CSharpPersistentInterfacesProvider">CSharpPersistentInterfacesProvider</see>.
	/// </summary>
	public partial class ImplementsPage : Page
	{
        private StateBag _statebag;

		/// <summary>
		/// Creates a new instance of the <see cref="InterfacePage">InterfacePage Class</see>.
		/// </summary>
        /// <param name="statebag">The plugin's statebag.</param>
        public ImplementsPage(PersistentProvider provider, StateBag statebag)
            : base(provider)
		{
			InitializeComponent();

            if (provider == null)
                throw new ArgumentNullException("provider", "Provider is null.");
            if (statebag == null)
                throw new ArgumentNullException("statebag", "Statebag is null.");
            _statebag = statebag;
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		/// <param name="project">The current project.</param>
		public override void PageOpening(Project project)
		{

			SetHeaderTitle(Resources.InterfacesHeaderTitle);
			SetHeaderDescription(Resources.InterfacesHeaderDescription);

            iDynamicExtensibleCheckBox.Checked = _statebag.IDynamicExtensible;
            iObjectNotificationCheckBox.Checked = _statebag.IObjectNotification;
            iPopulateHelperCheckBox.Checked = _statebag.IPopulateHelper;
            iSelfContainingObjectCheckBox.Checked = _statebag.ISelfContainingObject;
            iNotifyPropertyChangedCheckBox.Checked = _statebag.INotifyPropertyChanged;
		}

		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
            _statebag.IDynamicExtensible = iDynamicExtensibleCheckBox.Checked;
            _statebag.IObjectNotification = iObjectNotificationCheckBox.Checked;
            _statebag.IPopulateHelper = iPopulateHelperCheckBox.Checked;
            _statebag.ISelfContainingObject = iSelfContainingObjectCheckBox.Checked;
            _statebag.INotifyPropertyChanged = iNotifyPropertyChangedCheckBox.Checked;
			return true;
		}
	}
}
