#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.IO;
using Chili.Opf3.Wizard.Properties;

#endregion

namespace Chili.Opf3.Wizard
{
	/// <summary>
	/// This class logs the output of the object generating process.
	/// </summary>
	public sealed class OutputLogger
	{
		private string _path = null;

		/// <summary>
		/// Creates a new instance of the <see cref="OutputLogger">OutPutLogger Class</see>.
		/// </summary>
		/// <param name="path">The path of the log file.</param>
		public OutputLogger(string path)
		{
			if (path == null)
				throw new ArgumentNullException("path", "Path is null.");

			_path = path;

			WriteHeader();
		}

		/// <summary>
		/// Writes the header of the log file.
		/// </summary>
		private void WriteHeader()
		{
			using (TextWriter writer = File.CreateText(_path))
			{
				writer.WriteLine("{0} Log file", Resources.ProgramName);
				writer.WriteLine("Generated {0}", DateTime.Now.ToString());
				writer.WriteLine("\r\n");
			}
		}

		/// <summary>
		/// Adds an item to the log.
		/// </summary>
		/// <param name="message">The message of the item that is added.</param>
		public void AddToLog(string message)
		{
			using (TextWriter writer = File.AppendText(_path))
			{
				writer.WriteLine("[{0}] {1}", DateTime.Now.ToString(), message);
			}
		}

		/// <summary>
		/// Adds an item to the log.
		/// </summary>
		/// <param name="message">The message of the item that is added.</param>
		/// <param name="exception">The exception that happened.</param>
		public void AddToLog(string message, Exception exception)
		{
			using (TextWriter writer = File.AppendText(_path))
			{
				writer.WriteLine();
				writer.WriteLine("[{0}] {1}", DateTime.Now.ToString(), message);
				writer.WriteLine("  -> {0}", exception.Message);
				writer.WriteLine("  -> {0}", exception.StackTrace);
				writer.WriteLine();
			}
		}
	}
}
