#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Windows.Forms;
using System.IO;
using Chili.Opf3.Wizard.Shared;
using System.Reflection;

#endregion

namespace Chili.Opf3.Wizard
{
	/// <summary>
	/// This class loads all the plugins for the Wizard.
	/// </summary>
	public static class PluginLoader
	{
		private const string PLUGIN_FILTER = "*.dll";

		/// <summary>
		/// Loads and returns a list of classes that implement the <see cref="IObjectsProvider">IObjectsProvider</see> interface.
		/// </summary>
		public static IList<IObjectsProvider> LoadObjectsProvider()
		{
			// Create a new instance of the list storing the classes.
			IList<IObjectsProvider> objectsProvider = new List<IObjectsProvider>();

			foreach (string fileName in Directory.GetFiles(Application.StartupPath, PLUGIN_FILTER))
			{
				try
				{
					// Exceptions should bubble up. We have a problem if they happen here.
					Assembly assembly = Assembly.LoadFrom(fileName);
					// Loop over all public types and find those implementing the IPersistentGenerator interface.
					foreach (Type type in assembly.GetExportedTypes())
					{
						if (type.GetInterface(typeof(IObjectsProvider).Name) == null)
							continue;

						IObjectsProvider provider = (IObjectsProvider)Activator.CreateInstance(type);

						// Add the provider to the beginning if a persistent provider and to the end if another.
						if (provider is IPersistentObjectsProvider)
							objectsProvider.Insert(0, provider);
						else
							objectsProvider.Add(provider);
					}
				}
				catch
				{
					// Ignore all exceptions.
				}
			}

			return objectsProvider;
		}
	}
}
