#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.IO;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard
{
	/// <summary>
	/// Represents a program sesssion.
	/// </summary>
	public sealed class Session
	{
		private static Session _current;
		private List<IObjectsProvider> _objectProvider = new List<IObjectsProvider>();
		private ProjectManager _projectManager;

		/// <summary>
		/// Creates a new instance of the <see cref="Session">Session Class</see>.
		/// </summary>
		private Session()
		{
		}

		/// <summary>
		/// Returns the current session.
		/// </summary>
		public static Session Current
		{
			get
			{
				if (_current == null)
					_current = new Session();
				return _current;
			}
		}

		/// <summary>
		/// Specifies the current project.
		/// </summary>
		public Project Project
		{
			get { return this.ProjectManager.Project; }
		}

		/// <summary>
		/// Returns the project manager of the current session.
		/// </summary>
		public ProjectManager ProjectManager
		{
			get
			{
				if (_projectManager == null)
					_projectManager = new ProjectManager();
				return _projectManager;
			}
		}

		/// <summary>
		/// Returns the list of object provider.
		/// </summary>
        public List<IObjectsProvider> ObjectProvider
        {
            get { return _objectProvider; }
        }
	}
}
