#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.IO;
using System.Xml;
using System.Data.OleDb;

using Chili.Opf3.Wizard.Shared.Storages;

#endregion

namespace Chili.Opf3.Wizard
{
	/// <summary>
	/// This class loads the storages from the corresponding xml file.
	/// </summary>
	public sealed class StoragesManager : List<Storage>
	{
		private const string FILE_NAME = "Storages.xml";
		private const string SELECT_XPATH = "//storage";
		private const string STORAGES = "storages";
		private const string STORAGE = "storage";
		private const string ALIAS = "alias";
		private const string CONNECTION = "connection";
		private string _path;

		/// <summary>
		/// Creates a new instance of the <see cref="StoragesManager">StoragesManager Class</see>.
		/// </summary>
		public StoragesManager()
		{
			_path = string.Format("{0}\\{1}", Environment.CurrentDirectory, FILE_NAME);
		}

		/// <summary>
		/// Loads the content of the xml storages file in the manager.
		/// </summary>
		public void Load()
		{
			if (!File.Exists(_path))
				return;

			XmlDocument xml = new XmlDocument();
			try
			{
				xml.Load(_path);
			}
			catch
			{
				return;
			}

			XmlNodeList nodes = xml.SelectNodes(SELECT_XPATH);
			foreach (XmlNode node in nodes)
			{
				Storage storage = GetStorage(node);
				if (storage != null)
					Add(storage);
			}
		}

		/// <summary>
		/// Gets a single storage object from the file.
		/// </summary>
		/// <param name="storageNode">The node containing the storage data.</param>
		private Storage GetStorage(XmlNode storageNode)
		{
			string alias = null;
			string connectionString = null;

			foreach (XmlNode node in storageNode.ChildNodes)
			{
				switch (node.Name)
				{
					case ALIAS:
						alias = node.InnerText;
						break;
					case CONNECTION:
						connectionString = node.InnerText;
						break;
				}
			}

			if (alias != null && connectionString != null)
				return new Storage(alias, connectionString);
			return null;
		}

		/// <summary>
		/// Saves the content of the StorageManager to the file.
		/// </summary>
		public void Save()
		{
			XmlDocument xml = new XmlDocument();
			// Add the root <storages> element.
			XmlElement storagesElement = xml.CreateElement(STORAGES);
			xml.AppendChild(storagesElement);

			foreach (Storage storage in this)
			{
				// Add the <storage> element.
				XmlElement storageElement = xml.CreateElement(STORAGE);
				storagesElement.AppendChild(storageElement);

				// Add the <alias> element.
				XmlElement aliasElement = xml.CreateElement(ALIAS);
				storageElement.AppendChild(aliasElement);
				aliasElement.AppendChild(xml.CreateTextNode(storage.Alias));

				// Add the <connection> element.
				XmlElement connectionElement = xml.CreateElement(CONNECTION);
				storageElement.AppendChild(connectionElement);
				connectionElement.AppendChild(xml.CreateTextNode(storage.ConnectionString));
			}

			// Create the file and write the xml.
			using (TextWriter writer = File.CreateText(_path))
			{
				writer.Write(xml.OuterXml);
			}
		}
	}
}
