#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.UI.Pages;
using Chili.Opf3.Wizard.Shared.UI;

#endregion

namespace Chili.Opf3.Wizard.UI
{
	/// <summary>
	/// This class manages custom pages.
	/// </summary>
	public sealed class CustomPagesManager
	{
		private Wizard _wizard;
		private ListView _listView;
		private List<WizardPage> _pages = new List<WizardPage>();

		/// <summary>
		/// Creates a new instance of the <see cref="CustomPagesManager">CustomPagesManager Class</see>.
		/// </summary>
		/// <param name="listView">The listview containing the object provider.</param>
		/// <param name="wizard">The wizard itself.</param>
		public CustomPagesManager(ListView listView, Wizard wizard)
		{
			if (listView == null)
				throw new ArgumentNullException("listView", "ListView is null.");
			if (wizard == null)
				throw new ArgumentNullException("wizard", "Wizard is null.");

			_listView = listView;
			_wizard = wizard;
		}

		/// <summary>
		/// Manages the pages.
		/// </summary>
		public void ManagePages(int pluginsstartpage)
		{
			RemoveAllCustomPages();

			_wizard.SuspendLayout();
			try
			{
				foreach (ListViewItem item in _listView.Items)
				{
					if (!item.Checked)
						continue;

					IObjectsProvider provider = (IObjectsProvider)item.Tag;
					foreach (Page page in provider.Pages)
					{
						// Creates a new wizard page that hosts a custom page that hosts the user page.
						WizardPage wizardPage = new WizardPage(new CustomPage(page));

						// Insert the page in the wizard.
                        _wizard.Pages.Insert(pluginsstartpage, wizardPage);
						_pages.Add(wizardPage);
					}

                    // Deserialize the plugin data from the XML document.
                    XmlNode node = Session.Current.ProjectManager.GetObjectProviderNode((IObjectsProvider)item.Tag);

                    if (node != null)
                        ((IObjectsProvider)item.Tag).Deserialize(Session.Current.Project, Session.Current.ProjectManager.Xml, node);
                    else
                        ((IObjectsProvider)item.Tag).InitializeDefaults(Session.Current.Project);
				}
			}
			finally
			{
				_wizard.ResumeLayout();
			}
		}

		/// <summary>
		/// Removes all custom pages.
		/// </summary>
		private void RemoveAllCustomPages()
		{
			_wizard.SuspendLayout();
			try
			{
				// Remove the items from the wizard.
				foreach (WizardPage page in _pages)
				{
					_wizard.Pages.Remove(page);
				}
			}
			finally
			{
				_wizard.ResumeLayout();
			}

			// Clear the collection.
			_pages.Clear();
		}
	}
}
