#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Properties;
using System.Reflection;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.UI.Forms
{
	/// <summary>
	/// This class represents the about dialog of the wizard.
	/// </summary>
	public partial class AboutDialog : Form
	{
		/// <summary>
		/// Creates a new instance of the <see cref="AboutDialog">AboutDialog Class</see>.
		/// </summary>
		public AboutDialog()
		{
			InitializeComponent();

			summaryLabel.Text = string.Format(summaryLabel.Text, Resources.ProgramName, this.GetType().Assembly.GetName().Version.ToString());

			// Load all plugins.
			IList<IObjectsProvider> provider = PluginLoader.LoadObjectsProvider();
			foreach (IObjectsProvider p in provider)
			{
				pluginsListBox.Items.Add(p);
			}

			if (provider.Count > 0)
				pluginsListBox.SelectedIndex = 0;
		}

		/// <summary>
		/// Invoked every time the selected index changed.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void pluginsListBox_SelectedIndexChanged(object sender, EventArgs e)
		{
			aboutButton.Enabled = (pluginsListBox.SelectedIndex > -1);
		}

		/// <summary>
		/// Invoked every time the about button is clicked.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void aboutButton_Click(object sender, EventArgs e)
		{
			try
			{
				IObjectsProvider p = pluginsListBox.SelectedItem as IObjectsProvider;
				// Show the about dialog.
				p.ShowAboutDialog();
			}
			catch (Exception)
			{
				MessageBox.Show(Resources.NoAboutDialogAvailableText, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Information);
			}
		}
	}
}