#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Properties;
using Chili.Opf3.Wizard.Shared;

#endregion

namespace Chili.Opf3.Wizard.UI.Forms
{
	/// <summary>
	/// The main form of the wizard.
	/// </summary>
	public partial class MainForm : Form
	{
		private const int ABOUT_MESSAGE_ID = 310582;

		/// <summary>
		/// Creates a new instance of the Main Class.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();
			ExtendSystemMenu();

			// Set the program name as title of the form.
			this.Text = Resources.ProgramName;

			// Send the notification to the first page that is has been opened.
			welcomePage.PageOpening();
		}

		/// <summary>
		/// Extends the system menu by a custom item.
		/// </summary>
		private void ExtendSystemMenu()
		{
			// Get the handle to the system menu.
			int systemMenu = WinAPI.GetSystemMenu(this.Handle.ToInt32(), 0);
			WinAPI.AppendMenu(systemMenu, 0xA00, 0, null);
			WinAPI.AppendMenu(systemMenu, 0, ABOUT_MESSAGE_ID, Resources.SystemMenuAboutText); 
		}

		/// <summary>
		/// Sets the title of the header.
		/// </summary>
		/// <param name="value">Value that is set as header title.</param>
		public void SetHeaderTitle(string value)
		{
			header.Title = value;
		}

		/// <summary>
		/// Sets the description of the header.
		/// </summary>
		/// <param name="value">Value that is set as header description.</param>
		public void SetHeaderDescription(string value)
		{
			header.Description = value;
		}

		/// <summary>
		/// Invoked when the form is closed.
		/// </summary>
		private void Main_FormClosing(object sender, FormClosingEventArgs e)
		{
			// Skip the save process if no objectprovider has been selected.
			if (Session.Current.ObjectProvider.Count == 0)
				return;

			// Save the project to file.
			ProjectManager projectmanager = Session.Current.ProjectManager;
			e.Cancel = !projectmanager.Save();
		}

		#region Overriden Members

		/// <summary>
		/// The windows procedure of the window. This procedure receives all messages to the window.
		/// </summary>
		protected override void WndProc(ref Message m)
		{
			base.WndProc(ref m);
			
			// WM_SYSCOMMAND is 0x112.
			if (m.Msg == 0x112 && m.WParam.ToInt32() == ABOUT_MESSAGE_ID)
			{
				// Everything in here will run when menu is clicked.
				new AboutDialog().ShowDialog(this);
			}   
		}

		#endregion
	}
}