#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared.UI;
using MSDASC;
using ADODB;
using System.Data.OleDb;
using Chili.Opf3.Wizard.Properties;

#endregion

namespace Chili.Opf3.Wizard.UI.Forms
{
	/// <summary>
	/// This class allows to add a new storage to the list of storages.
	/// </summary>
	public partial class StorageDialog : BaseDialog
	{
		private Storage _storage;

		/// <summary>
		/// Creates a new instance of the <see cref="StorageDialog">StorageDialog Class</see>.
		/// </summary>
		public StorageDialog()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Creates a new instance of the <see cref="StorageDialog">StorageDialog Class</see>.
		/// </summary>
		public StorageDialog(Storage storage) : this()
		{
			_storage = storage;
			PopulateControls();
		}

		/// <summary>
		/// Populates the controls with data.
		/// </summary>
		private void PopulateControls()
		{
			if (_storage == null)
				return;

			aliasTextBox.Text = _storage.Alias;
			connectionStringTextBox.Text = _storage.ConnectionString;
		}

		/// <summary>
		/// Returns the selected storage or null if Cancel has been clicked.
		/// </summary>
		public Storage Storage
		{
			get { return _storage; }
			private set { _storage = value; }
		}

		/// <summary>
		/// Invoked during the click on the button to create a new connection string.
		/// </summary>
		private void createConnectionStringButton_Click(object sender, EventArgs e)
		{
			DataLinks dlDlg = new DataLinks();

			if (connectionStringTextBox.Text.Length > 0)
			{
				object adoConn = new ConnectionClass();
				((_Connection)adoConn).ConnectionString = connectionStringTextBox.Text;
				if (dlDlg.PromptEdit(ref adoConn))
					connectionStringTextBox.Text = ((_Connection)adoConn).ConnectionString;
			}
			else
			{
				// Cast the generic object that PromptNew returns to an ADODB._Connection.
				dlDlg.hWnd = this.Handle.ToInt32();
				_Connection adoConn = (_Connection)dlDlg.PromptNew();

				if (adoConn != null)
					connectionStringTextBox.Text = adoConn.ConnectionString;
			}
		}

		/// <summary>
		/// Invoked during the close of the form.
		/// </summary>
		private void StorageDialog_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (DialogResult != DialogResult.OK)
				return;

			e.Cancel = !PopulateStorage();
		}

		/// <summary>
		/// Populates the storage object.
		/// </summary>
		/// <returns>True if the object was populates successfully.</returns>
		private bool PopulateStorage()
		{
			// Check if the alias has been filled out.
			if (aliasTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.MissingDatabaseAliasErrorText, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}
			// ... and if a valid connection string has been given.
			if (connectionStringTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.MissingDatabaseConnectionStringErrorText, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}

			if (_storage != null)
			{
				// Modifiy the class if we are in edit mode.
				_storage.Alias = aliasTextBox.Text;
				_storage.ConnectionString = connectionStringTextBox.Text;
			}
			else
			{
				// Add a storage if we are in new mode.
				_storage = new Storage(aliasTextBox.Text, connectionStringTextBox.Text);
			}

			return true;
		}
	}
}