#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Properties;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Shared.UI;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.UI.Forms;

#endregion

namespace Chili.Opf3.Wizard.UI.Forms
{
	/// <summary>
	/// This dialog allows to edit one relation item.
	/// </summary>
	public partial class TypeConversionDialog : BaseDialog
	{
        private TypeConversionPair _typeconversion;

		/// <summary>
        /// Creates a new instance of the <see cref="RelationsItemDialog">TypeConversionDialog Class</see>.
		/// </summary>
		/// <param name="mode">The mode of the dialog.</param>
        /// <param name="typeconversion">The TypeConversion that is edited.</param>
        public TypeConversionDialog(DialogModes mode, TypeConversionPair  typeconversion)
		{
			InitializeComponent();

            if (typeconversion == null)
                throw new ArgumentNullException("typeconversion", "Typeconversion is null.");


            _typeconversion = typeconversion;

            // fill type combobox
            languageComboBox.Items.Clear();
            languageComboBox.Items.AddRange(Session.Current.Project.TypeConverter.Languages.ToArray());  
            basetypeCombobox.Items.Clear(); 
            basetypeCombobox.Items.AddRange(Session.Current.Project.TypeConverter.BaseTypes.ToArray());  


            // Set the labels with the persistent names.
            languageComboBox.Text = _typeconversion.Language;
            basetypeCombobox.Text = _typeconversion.BaseType;
            targettypeTextBox.Text = _typeconversion.TargetType;
            initializerTextBox.Text = _typeconversion.Initializer;
            nameconditionTextBox.Text = _typeconversion.NameCondition;
            ignorecaseCheckBox.Checked = _typeconversion.IgnoreCase;

            if (mode == DialogModes.New)
                this.Text = Resources.NewConversionTypePairDialogTitle;
            else
            {
                this.Text = Resources.EditConversionTypePairDialogTitle;
            }
		}

		/// <summary>
		/// Populates the object with data.
		/// </summary>
		private bool PopulateObject()
		{
            if (languageComboBox.Text.Length == 0)
            {
                MessageBox.Show(Resources.MissingLanguage, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
                languageComboBox.Focus();
                return false;
            }
            if (basetypeCombobox.Text.Length == 0)
            {
                MessageBox.Show(Resources.MissingBaseType, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
                basetypeCombobox.Focus();
                return false;
            }

            if (targettypeTextBox.Text.Length == 0)
            {
                MessageBox.Show(Resources.MissingTargetType, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
                targettypeTextBox.Focus();
                return false;
            }

            _typeconversion.Language = languageComboBox.Text;
            _typeconversion.BaseType = basetypeCombobox.Text;
            _typeconversion.TargetType = targettypeTextBox.Text;
            _typeconversion.Initializer = initializerTextBox.Text;
            _typeconversion.NameCondition = nameconditionTextBox.Text;
            _typeconversion.IgnoreCase = ignorecaseCheckBox.Checked;

            return true;
        }

		
		/// <summary>
		/// Invoked each time the form is about to close.
		/// </summary>
		private void TypeConversionDialog_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (this.DialogResult != DialogResult.OK)
				return;

			e.Cancel = (!PopulateObject());
		}
	}
}