#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.Properties;
using System.Text.RegularExpressions;

#endregion

namespace Chili.Opf3.Wizard.UI.Pages
{
	/// <summary>
	/// This class represents the page that allows to enter additional data for the persistent objects.
	/// </summary>
	public partial class AdditionalDataPage : BasePage
	{
		/// <summary>
		/// Creates a new instance of the <see cref="AdditionalDataPage">AdditionalDataPage Class</see>.
		/// </summary>
		public AdditionalDataPage()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		public override void PageOpening()
		{
			// Set the title and the description of the summary page header.
			SetHeaderTitle(Resources.AdditionalDataPageHeaderTitle);
			SetHeaderDescription(Resources.AdditionalDataPageHeaderDescription);

			Project project = Session.Current.Project;
			if (project.AutorInfo.Name != null)
				nameTextBox.Text = project.AutorInfo.Name;
			if (project.AutorInfo.Copyright != null)
				copyrightTextBox.Text = project.AutorInfo.Copyright;
			if (project.Namespace != null)
				namespaceTextBox.Text = project.Namespace;
			if (project.OutputDirectoy != null)
				outputFolderTextBox.Text = project.OutputDirectoy;
		}

		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
			if (!next)
				return true;

			// Check if the namespace text box has been compiled.
			if (namespaceTextBox.Text.Trim().Length == 0)
			{
				MessageBox.Show(Resources.MissingNamespaceText, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}

			// Check if the output folder textbox has been compiled.
			if (outputFolderTextBox.Text.Length == 0)
			{
				MessageBox.Show(Resources.MissingOutputDirectoryText, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}

			// Set the properties of the project.
			Project project = Session.Current.Project;
			project.OutputDirectoy = outputFolderTextBox.Text;
			project.Namespace = namespaceTextBox.Text;
			project.AutorInfo.Name = nameTextBox.Text;
			project.AutorInfo.Copyright = copyrightTextBox.Text;
			return true;
		}

		/// <summary>
		/// Click on the button that allows to select the final output folder.
		/// </summary>
		private void selectFolderButton_Click(object sender, EventArgs e)
		{
			// Set the selected path to the path in the text box.
			folderBrowserDialog.SelectedPath = outputFolderTextBox.Text;

			if (folderBrowserDialog.ShowDialog(this) == DialogResult.OK)
			{
				outputFolderTextBox.Text = folderBrowserDialog.SelectedPath;
			}
		}
	}
}
