#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.UI.Forms;

#endregion

namespace Chili.Opf3.Wizard.UI.Pages
{
	/// <summary>
	/// The base page of all controls placed on the wizard control.
	/// </summary>
	public class BasePage : UserControl
	{
		WizardPage _wizardpage;

		/// <summary>
		/// Invoked during load of the page.
		/// </summary>
		protected override void OnLoad(EventArgs e)
		{
			base.OnLoad(e);

			if (!this.DesignMode)
			{
				// Get the parent wizard page.
				WizardPage parent = (WizardPage)this.Parent;

				// Register all required event handler.
				parent.ShowFromBack += new EventHandler(parent_Show);
				parent.ShowFromNext += new EventHandler(parent_Show);
				parent.CloseFromBack += new PageEventHandler(parent_CloseFromBack);
				parent.CloseFromNext += new PageEventHandler(parent_CloseFromNext);

				_wizardpage = parent;
			}
		}

		/// <summary>
		/// Invoked each time the current page is closed when the back button is clicked.
		/// </summary>
		private void parent_CloseFromBack(object sender, PageEventArgs e)
		{
			if (!PageClosing(false))
			{
				// Don't allow to switch page if returned false.
				e.Page = _wizardpage;
			}
		}

		/// <summary>
		/// Invoked each time the current page is closed when the next button is clicked.
		/// </summary>
		private void parent_CloseFromNext(object sender, PageEventArgs e)
		{
			if (!PageClosing(true))
			{
				// Don't allow to switch page if returned false.
				e.Page = _wizardpage;
			}
		}

		/// <summary>
		/// Invoked each time the current page is opened.
		/// </summary>
		void parent_Show(object sender, EventArgs e)
		{
			PageOpening();
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		public virtual void PageOpening()
		{
		}

		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public virtual bool PageClosing(bool next)
		{
			return true;
		}

		/// <summary>
		/// Specifies the title of the header.
		/// </summary>
		/// <param name="value">Value set as header title.</param>
		public void SetHeaderTitle(string value)
		{
			((MainForm)this.Parent.Parent.Parent).SetHeaderTitle(value);
		}

		/// <summary>
		/// Specifies the description of the header.
		/// </summary>
		/// <param name="value">Value set as header description.</param>
		public void SetHeaderDescription(string value)
		{
			((MainForm)this.Parent.Parent.Parent).SetHeaderDescription(value);
		}
	}
}
