#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Shared.UI;
using Chili.Opf3.Wizard.Properties;

#endregion

namespace Chili.Opf3.Wizard.UI.Pages
{
	/// <summary>
	/// This is a custom page displayed by a class that implements the 
	/// <see cref="Chili.Opf3.Wizard.Shared.IUtilityObjectProvider">IUtilityObjectProvider</see> interface.
	/// </summary>
	public partial class CustomPage : BasePage
	{
		private Page _page;

		/// <summary>
		/// Creates a new instance of the <see cref="CustomPage">CustomPage Class</see>.
		/// </summary>
		public CustomPage(Page page)
		{
			InitializeComponent();

			if (page == null)
				throw new ArgumentNullException("page", "Page is null.");
			_page = page;

			// Set the name of the provider in the label.
			pluginNameLabel.Text = string.Format(Resources.PluginInfoBarText, page.Provider.Name, 
				(page.Provider.LanguageName != null ? page.Provider.LanguageName : Resources.None));
			page.Size = new Size(this.Width, this.Height - pluginTextPanel.Height);
			page.Location = new Point(0, pluginTextPanel.Height);
			this.Controls.Add(page);
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		public override void PageOpening()
		{
			_page.PageOpening(Session.Current.Project);
		}

		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
			return _page.PageClosing(next);
		}
	}
}
