#region Developer's comment header
/* 
 * copyright:  2005-2006 Chili Software. All rights reserved.
 *
 */
#endregion
#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Chili.Opf3.Wizard.Properties;
using Chili.Opf3.Wizard.Shared.Storages;
using Chili.Opf3.Wizard.Shared;
using Chili.Opf3.Wizard.UI.Forms;
using System.Xml;

#endregion

namespace Chili.Opf3.Wizard.UI.Pages
{
	/// <summary>
	/// This class represents the first page of the wizard.
	/// </summary>
	public partial class WelcomePage : BasePage
	{
		private IList<IObjectsProvider> _objectProvider;
		private CustomPagesManager _customPagesManager;

		/// <summary>
		/// Creates a new instance of the <see cref="WelcomePage">WelcomePage Class</see>.
		/// </summary>
		public WelcomePage()
		{
			InitializeComponent();
		}

		/// <summary>
		/// Invoked each time the page is opened.
		/// </summary>
		public override void PageOpening()
		{
			// Set the title and the description of the welcome page header.
			SetHeaderTitle(Resources.WelcomePageHeaderTitle);
			SetHeaderDescription(Resources.WelcomePageHeaderDescription);

			if (_objectProvider == null)
			{
				_objectProvider = PluginLoader.LoadObjectsProvider();
				DatabindObjectProvider();

				// Load the project if the filename is not null.
				if (Session.Current.ProjectManager.Filename != null)
				{
					LoadProject();
				}
			}

			// Create an instance of the custom pages manager.
			if (_customPagesManager == null)
				_customPagesManager = new CustomPagesManager(objectsProviderListView, (Wizard)this.Parent.Parent);
		}

		/// <summary>
		/// Invoked each time the page is closed.
		/// </summary>
		/// <param name="next">True if the next button has been clicked. False on all other.</param>
		public override bool PageClosing(bool next)
		{
			if (!next)
				return true;

			if (objectsProviderListView.CheckedItems.Count == 0)
			{
				MessageBox.Show(Resources.MissingSelectedPluginDescription, Resources.ProgramName, MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}

			Session session = Session.Current;
			// Clear the list of provider first.
			session.ObjectProvider.Clear();
			Project project = session.Project;
			// Add all checked utility generators to the list of utilties generator.
			foreach (ListViewItem item in objectsProviderListView.Items)
			{
				if (!item.Checked)
					continue;

				IObjectsProvider provider = item.Tag as IObjectsProvider;
				session.ObjectProvider.Add(provider);
			}

			// Manage the custom pages.
			_customPagesManager.ManagePages(5);

			return true;
		}

		/// <summary>
		/// Binds the list of object generators to the list view.
		/// </summary>
		private void DatabindObjectProvider()
		{
			// Add all provider to the listbox.
			foreach (IObjectsProvider provider in _objectProvider)
			{
				ListViewItem item = new ListViewItem(provider.Name);
				item.SubItems.Add(provider.LanguageName);
				item.SubItems.Add(provider.Version);
				item.SubItems.Add(provider.Description);
				item.ImageIndex = (provider is IPersistentObjectsProvider ? 0 : 1);
				item.Tag = provider;

				objectsProviderListView.Items.Add(item);
			}
		}

        /// <summary>
        /// Invoked each time the open project button is clicked.
        /// </summary>
        private void openprojectButton_Click(object sender, EventArgs e)
        {
			LoadProject();
		}

		/// <summary>
		/// Loads a project.
		/// </summary>
		private void LoadProject()
		{
			ProjectManager projectmanager = Session.Current.ProjectManager;
			if (projectmanager.Filename == null)
			{
				if (!projectmanager.Open())
					return;
			}

			// Set the file name in the label.
			loadedProjectLabel.Text = projectmanager.Filename;

			// select/unselect plugins
			foreach (ListViewItem item in objectsProviderListView.Items)
			{
				// Deserialize the plugin data from the XML document.
				XmlNode node = Session.Current.ProjectManager.GetObjectProviderNode((IObjectsProvider)item.Tag);
				item.Checked = (node != null);
			}
		}

		/// <summary>
		/// Invoked each time the new project button is clicked.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void newProjectButton_Click(object sender, EventArgs e)
		{
			// Create a new project in to the project manager. Closes the old one.
			Session.Current.ProjectManager.NewProject();

			loadedProjectLabel.Text = Resources.NewProject;
		}
	}
}
