using System;
using System.Collections.Generic;
using System.Text;
using Chili.Opf3.Wizard.SimplePlugin.Properties;

namespace Chili.Opf3.Wizard.SimplePlugin
{
	/// <summary>
	/// This class represents one item that is created by the Simple Plugin. It implements the IGeneratedObject
	/// interface that is implemented by all objects that are generated by a plug-in.
	/// </summary>
	public sealed class SampleItem : Chili.Opf3.Wizard.Shared.IGeneratedObject
	{
		// This is a unique id. It is required by the wizard to identify the item in the list that is
		// shown on the final page of the wizard (the page that is shown while generating objects).
		private string _id = Guid.NewGuid().ToString();
		private Chili.Opf3.Wizard.Shared.Storages.Table _table;

		/// <summary>
		/// Creates a new instance of the SampleItem Class.
		/// </summary>
		/// <param name="table">The table associated with the item.</param>
		public SampleItem(Chili.Opf3.Wizard.Shared.Storages.Table table)
		{
			if (table == null)
				throw new ArgumentNullException("table", "Table is null.");

			_table = table;
		}

		/// <summary>
		/// Returns if the item should be generated.
		/// </summary>
		public bool Generate
		{
			get { return _table.Generate; }
		}

		#region IGeneratedObject Members

		/// <summary>
		/// Returns the ID of the object. This is a unique identifier that is required for synchronization with the display.
		/// </summary>
		public string ID
		{
			get { return _id; }
		}

		/// <summary>
		/// Returns the name of the object. Is displayed in the list when generating the objects.
		/// </summary>
		public string Name
		{
			get { return string.Format(Resources.SampleItemName, _table.PersistentName); }
		}

		#endregion
	}
}
