//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: BeforeObjectPersistingEventArgs.cs
//
//  Description: EventArgs for ObjectContext events fired before persist.
// 
//--------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;

namespace Chili.Opf3
{
	/// <summary>
	/// EventArgs used in the <see cref="Opf3.ObjectContext">ObjectContext</see> events
	/// that are invoked before the persist process of an object.
	/// </summary>
	/// <remarks>
	/// This class is used by the <see cref="Opf3.ObjectContext">ObjectContext</see> in
	/// events that are invoked before the persist process of an object to send additional event
	/// data. The data contains the object that is persisted.
	/// </remarks>
	[Serializable]
	public sealed class BeforeObjectPersistingEventArgs : EventArgs
	{
		private object _obj;
		
		/// <summary>
		/// Creates a new instance of the<see cref="BeforeObjectPersistingEventArgs">BeforeObjectPersistingEventArgs Class</see>.
		/// </summary>
		/// <param name="obj">The object that is affected by the current operation. This object is persisted to the storage. </param>
		/// <exception cref="System.ArgumentNullException">Query is null, obj is null or objectInfo is null.</exception>
		internal BeforeObjectPersistingEventArgs(object obj)
        {
            if (obj == null)
                throw new ArgumentNullException("obj");

            _obj = obj;
        }

		/// <summary>
		/// Returns the object that is affected by the current operation. This object is
		/// persisted to the storage.
		/// </summary>
		/// <value>The object affected by the current operation.</value>
		public object Object
		{
			get { return _obj; }
		}
	}
}
