﻿//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: OEConcat.cs
//
//  Description: Concat for the ObjectExpression.
// 
//--------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;

namespace Chili.Opf3.Query.OPathParser
{
	/// <summary>
	/// Represents a concat expression in the OPath statement. 
	/// </summary>
	/// <remarks>
	/// Concat expression (And, Or) in a OPath statement are converted to this class when OPath is compiled.
	/// </remarks>
	[Serializable]
	public sealed class OEConcat : OEItem
	{
		private string _value;

		/// <summary>
		/// Creates a new instance of the <see cref="OEConcat">OEConcat Class</see>.
		/// </summary>
		/// <param name="value">Value of the command.</param>
		internal OEConcat(string value)
		{
			_value = value; 
		}

		/// <summary>
		/// Returns the value of the concat.
		/// </summary>
		/// <value>The value of the concat.</value>
		public string Value
		{
			get { return _value; }
		}
	}
}
