﻿//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: OEInlineParameter.cs
//
//  Description: Inline parameter for the ObjectExpression.
// 
//--------------------------------------------------------------------------

using System;

namespace Chili.Opf3.Query.OPathParser
{
	/// <summary>
	/// Represents an inline parameter in the OPath statement. 
	/// </summary>
	/// <remarks>
	/// Inline parameters in a OPath statement are converted to this class when OPath is compiled. Those
	/// kind of parameters should only be used for non-dynamic parameters.
	/// </remarks>
	[Serializable]
	public sealed class OEInlineParameter : OEItem
	{
		private string _value;

		/// <summary>
		/// Creates a new instance of the <see cref="OEInlineParameter">OEInlineParameter Class</see>.
		/// </summary>
		/// <param name="value">The value of the inline parameter. For example a string or a numeric value.</param>
		internal OEInlineParameter(string value)
		{
			_value = value;
		}

		/// <summary>
		/// Returns the value of the inline parameter.
		/// </summary>
		/// <value>The value of the inline parameter.</value>
		public string Value
		{
			get { return _value; }
		}
	}
}
