﻿//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: QueryTypes.cs
//
//  Description: Specifies the type of the query.
// 
//--------------------------------------------------------------------------

using System;

namespace Chili.Opf3.Query
{
	/// <summary>Contains different types of an <see cref="IQuery">IQuery</see>.</summary>
	/// <remarks>
	/// This enumeration contains the types of an <see cref="IQuery">IQuery</see>. The
	/// type of the query should be discovered by the <see cref="IQuery">IQuery</see>
	/// itself.
	/// </remarks>
	[Serializable]
	public enum QueryTypes
	{
		/// <summary>
		/// Queries marked with this member of the enumeration insert objects in the
		/// storage.
		/// </summary>
		Insert,
		/// <summary>
		/// Queries marked with this member of the enumeration update objects in the
		/// storage.
		/// </summary>
		Update,
		/// <summary>
		/// Queries marked with this member of the enumeration load objects from the storage.
		/// </summary>
		Load,
		/// <summary>
		/// Queries marked with this member of the enumeration delete objects from the
		/// storage.
		/// </summary>
		Delete,
		/// <summary>
		/// The type of the query couldn't be estimated or is unknown.
		/// </summary>
		Unknown
	}
}
