//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: SingleCallObjectContextFactoryPolicy.cs
//
//  Description: Creates a new ObjectContext on each call.
// 
//--------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;

namespace Chili.Opf3
{
	/// <summary>
	/// This class creates a new <see cref="ObjectContext">ObjectContext</see> instance
	/// on each call of the <see cref="ObjectContextFactory">ObjectContextFactory</see>'s
	/// GetContext method.
	/// </summary>
	public class SingleCallObjectContextFactoryPolicy : ObjectContextFactoryPolicyBase
	{
		/// <summary>
		/// Creates a new instance of the <see cref="SingleCallObjectContextFactoryPolicy">SingleCallObjectContextFactoryPolicy Class</see>.
		/// </summary>
		/// <param name="creator">The delegate that creates new <see cref="ObjectContext">ObjectContext</see> instances.</param>
		public SingleCallObjectContextFactoryPolicy(ObjectContextFactoryCreatorDelegate creator)
			: base(creator)
		{
		}

		/// <summary>
		/// Returns whether a new <see cref="ObjectContext">ObjectContext</see> instance is required.
		/// </summary>
		/// <returns>True if a new instance is required; false otherwise.</returns>
		protected override bool IsNewObjectContextRequired()
		{
			return true;
		}

		/// <summary>
		/// Stores the new <see cref="ObjectContext">ObjectContext</see> instance.
		/// </summary>
		/// <param name="context">The <see cref="ObjectContext">ObjectContext</see> to store.</param>
		/// <returns>The <see cref="ObjectContext">ObjectContext</see> instance that has been stored.</returns>
		protected override ObjectContext StoreNewObjectContext(ObjectContext context)
		{
			return context;
		}

		/// <summary>
		/// Gets an existing <see cref="ObjectContext">ObjectContext</see> instance.
		/// </summary>
		/// <returns>An <see cref="ObjectContext">ObjectContext</see> instance.</returns>
		protected override ObjectContext GetExistingObjectContext()
		{
			// Not supported. Should never get called!
			throw new NotSupportedException();
		}
	}
}
