﻿//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: ForeignKeyViolationException.cs
//
//  Description: Throw if a foreign key is violated.
// 
//--------------------------------------------------------------------------

using System;
using Chili.Opf3.Query;

namespace Chili.Opf3.Storages
{
	/// <summary>
	/// Exception is thrown if a foreign key has been violated while persisting an object.
	/// </summary>
	[Serializable]
	public sealed class ForeignKeyViolationException : StorageException
	{
		/// <summary>
		/// Creates a new instance of the
		/// <see cref="ForeignKeyViolationException">ForeignKeyViolationException Class</see>.
		/// </summary>
		private ForeignKeyViolationException(System.Runtime.Serialization.SerializationInfo info,
		  System.Runtime.Serialization.StreamingContext context) : base(info, context)
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		/// <param name="query">Query that has been executed before the exception has been thrown.</param>
		public ForeignKeyViolationException(IQuery query) : base(query)
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		/// <param name="message">A message that describes the current exception.</param>
		/// <param name="query">Query that has been executed before the exception has been thrown.</param>
		public ForeignKeyViolationException(string message, IQuery query) : base(message, query)
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		/// <param name="message">A message that describes the current exception.</param>
		/// <param name="inner">The exception that caused the current exception.</param>
		/// <param name="query">Query that has been executed before the exception has been thrown.</param>
		public ForeignKeyViolationException(string message, System.Exception inner, IQuery query) 
			: base(message, inner, query)
		{
		}
	}
}
