﻿//--------------------------------------------------------------------------
// 
//  Copyright (c) Chili Software.  All rights reserved. 
// 
//  File: PrimaryKeyViolationException.cs
//
//  Description: Exception is thrown if a primary key is violated.
// 
//--------------------------------------------------------------------------

using System;
using Chili.Opf3.Query;

namespace Chili.Opf3.Storages
{
	/// <summary>
	/// Exception is thrown if a primary key has been violated while persisting an object.
	/// </summary>
	[Serializable]
	public sealed class PrimaryKeyViolationException : StorageException
	{
		/// <summary>
		/// Creates a new instance of the
		/// <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		private PrimaryKeyViolationException(System.Runtime.Serialization.SerializationInfo info,
		  System.Runtime.Serialization.StreamingContext context) : base(info, context)
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		/// <param name="query">Query that has been executed before the exception has been thrown.</param>
		public PrimaryKeyViolationException(IQuery query) : base(query)
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		/// <param name="message">A message that describes the current exception.</param>
		/// <param name="query">Query that has been executed before the exception has been thrown.</param>
		public PrimaryKeyViolationException(string message, IQuery query) : base(message, query)
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="PrimaryKeyViolationException">PrimaryKeyViolationException Class</see>.
		/// </summary>
		/// <param name="message">A message that describes the current exception.</param>
		/// <param name="inner">The exception that caused the current exception.</param>
		/// <param name="query">Query that has been executed before the exception has been thrown.</param>
		public PrimaryKeyViolationException(string message, System.Exception inner, IQuery query) 
			: base(message, inner, query)
		{
		}
	}
}
